@@ -6,4 +6,6 @@ pref("intl.locale.matchOS", true);
 
 // enable fixed-up typeaheadfind extension
 pref("accessibility.typeaheadfindsea", true);
+// see bug #141963
+pref("accessibility.typeaheadfindsea.autostart", false);
 
