@@ -16,7 +16,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ContentHandler.h,v 1.25 2004/11/16 22:36:10 chpe Exp $
+ *  $Id: ContentHandler.h,v 1.26 2004/12/31 16:09:39 chpe Exp $
  */
 
 #ifndef CONTENT_HANDLER_H
@@ -24,7 +24,7 @@
 
 #include "config.h"
 
-#include "ephy-embed-shell.h"
+#include "ephy-file-helpers.h"
 
 #include <libgnomevfs/gnome-vfs-mime-handlers.h>
 
