@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: EphyBrowser.cpp,v 1.73 2005/01/05 20:09:09 chpe Exp $
+ *  $Id: EphyBrowser.cpp,v 1.75 2005/01/24 13:43:58 chpe Exp $
  */
 
 #include "mozilla-config.h"
@@ -24,10 +24,13 @@
 
 #include "EphyBrowser.h"
 #include "EphyUtils.h"
+#include "EventContext.h"
 #include "ephy-embed.h"
 #include "ephy-string.h"
 #include "ephy-debug.h"
 #include "print-dialog.h"
+#include "mozilla-embed.h"
+#include "mozilla-embed-event.h"
 
 #include <gtkmozembed_internal.h>
 #include <unistd.h>
@@ -57,6 +60,8 @@
 #include "nsIDOMDocument.h"
 #include "nsIDOM3Document.h"
 #include "nsIDOMEvent.h"
+#include "nsIDOMKeyEvent.h"
+#include "nsIDOMMouseEvent.h"
 #include "nsIDOMNSEvent.h"
 #include "nsIDOMEventTarget.h"
 #include "nsIDOMPopupBlockedEvent.h"
@@ -96,6 +101,8 @@
 
 static PRUnichar DOMLinkAdded[] = { 'D', 'O', 'M', 'L', 'i', 'n', 'k',
 				    'A', 'd', 'd', 'e', 'd', '\0' };
+static PRUnichar ContextMenu[] = { 'c', 'o', 'n', 't', 'e', 'x', 't', 'm',
+				   'e', 'n', 'u', '\0' };
 static PRUnichar DOMPopupBlocked[] = { 'D', 'O', 'M', 'P', 'o', 'p',
 				       'u', 'p', 'B', 'l', 'o', 'c',
 				       'k', 'e', 'd', '\0' };
@@ -107,7 +114,7 @@ static PRUnichar DOMModalDialogClosed[] = { 'D', 'O', 'M', 'M', 'o', 'd', 'a',
 					    'l', 'D', 'i', 'a', 'l', 'o', 'g',
 					    'C', 'l', 'o', 's', 'e', 'd', '\0' };
 
-EphyEventListener::EphyEventListener(void)
+EphyEventListener::EphyEventListener()
 : mOwner(nsnull)
 {
 	LOG ("EphyEventListener ctor (%p)", this)
@@ -181,15 +188,18 @@ EphyFaviconEventListener::HandleEvent(nsIDOMEvent* aDOMEvent)
 		/* disallow subframes to set favicon */
 		if (domWinAsISupports != topDomWinAsISupports) return NS_OK;
 
-		nsCOMPtr<nsIDOM3Document> doc = do_QueryInterface (domDoc);
+		nsCOMPtr<nsIDOM3Document> doc (do_QueryInterface (domDoc));
 		NS_ENSURE_TRUE (doc, NS_ERROR_FAILURE);
 
 		nsEmbedString spec;
 		rv = doc->GetDocumentURI (spec);
 		NS_ENSURE_SUCCESS (rv, NS_ERROR_FAILURE);
 
+                nsEmbedCString encoding;
+                mOwner->GetEncoding (encoding);
+
 		nsCOMPtr<nsIURI> docUri;
-		EphyUtils::NewURI (getter_AddRefs(docUri), spec);
+		EphyUtils::NewURI (getter_AddRefs(docUri), spec, encoding.get());
 		NS_ENSURE_TRUE (docUri, NS_ERROR_FAILURE);
 
 		nsEmbedCString faviconUrl;
@@ -328,10 +338,104 @@ EphyModalAlertEventListener::HandleEvent (nsIDOMEvent * aDOMEvent)
 	return NS_OK;
 }
 
+EphyContextMenuListener::EphyContextMenuListener()
+: mOwner(nsnull)
+{
+	LOG ("EphyContextMenuListener ctor (%p)", this)
+}
+
+EphyContextMenuListener::~EphyContextMenuListener()
+{
+	LOG ("EphyContextMenuListener dtor (%p)", this)
+}
+
+NS_IMPL_ISUPPORTS1(EphyContextMenuListener, nsIDOMContextMenuListener)
+
+nsresult
+EphyContextMenuListener::Init(EphyBrowser *aOwner)
+{
+	mOwner = aOwner;
+	return NS_OK;
+}
+
+NS_IMETHODIMP
+EphyContextMenuListener::ContextMenu (nsIDOMEvent* aDOMEvent)
+{
+	nsCOMPtr<nsIDOMMouseEvent> mouseEvent = do_QueryInterface(aDOMEvent);
+	NS_ENSURE_TRUE (mouseEvent, NS_ERROR_FAILURE);
+
+	MozillaEmbedEvent *info;
+	info = mozilla_embed_event_new (NS_STATIC_CAST (gpointer, aDOMEvent));
+
+	nsresult rv;
+	EventContext context;
+	context.Init (mOwner);
+        rv = context.GetMouseEventInfo (mouseEvent, MOZILLA_EMBED_EVENT (info));
+
+	/* Don't do any magic handling if we can't actually show the context
+	 * menu, this can happen for XUL pages (e.g. about:config)
+	 */
+	if (NS_FAILED (rv))
+	{
+		g_object_unref (info);
+		return NS_OK;   
+	}
+
+	if (info->button == 0)
+	{
+		/* Translate relative coordinates to absolute values, and try
+		 * to avoid covering links by adding a little offset
+		 */
+		int x, y;
+		gdk_window_get_origin (GTK_WIDGET (mOwner->mEmbed)->window, &x, &y);
+		info->x += x + 6;       
+		info->y += y + 6;
+
+		// Set the keycode to something sensible
+		info->keycode = nsIDOMKeyEvent::DOM_VK_CONTEXT_MENU;
+	}
+
+	if (info->modifier == GDK_CONTROL_MASK)
+	{
+		info->context = EPHY_EMBED_CONTEXT_DOCUMENT;
+	}
+
+	gboolean retval = FALSE;
+	nsCOMPtr<nsIDOMDocument> domDoc;
+	rv = context.GetTargetDocument (getter_AddRefs(domDoc));
+	if (NS_SUCCEEDED(rv))
+	{
+		mOwner->PushTargetDocument (domDoc);
+
+		g_signal_emit_by_name (mOwner->mEmbed, "ge_context_menu",
+				       info, &retval);
+
+		mOwner->PopTargetDocument ();
+	}
+
+	/* We handled the event, block javascript calls */
+	if (retval)
+	{
+		aDOMEvent->PreventDefault();
+		aDOMEvent->StopPropagation();
+	}
+	
+	g_object_unref (info);
+
+	return NS_OK;
+}
+
+NS_IMETHODIMP
+EphyContextMenuListener::HandleEvent (nsIDOMEvent* aDOMEvent)
+{
+	return NS_ERROR_NOT_IMPLEMENTED;
+}
+
 EphyBrowser::EphyBrowser ()
 : mFaviconEventListener(nsnull)
 , mPopupBlockEventListener(nsnull)
 , mModalAlertListener(nsnull)
+, mContextMenuListener(nsnull)
 , mInitialized(PR_FALSE)
 {
 	LOG ("EphyBrowser ctor (%p)", this)
@@ -379,6 +483,12 @@ nsresult EphyBrowser::Init (GtkMozEmbed *mozembed)
 	rv = mModalAlertListener->Init (this);
 	NS_ENSURE_SUCCESS (rv, NS_ERROR_FAILURE);
 
+	mContextMenuListener = new EphyContextMenuListener();
+	if (!mContextMenuListener) return NS_ERROR_OUT_OF_MEMORY;
+
+	rv = mContextMenuListener->Init (this);
+	NS_ENSURE_SUCCESS (rv, NS_ERROR_FAILURE);
+
  	rv = GetListener();
 	NS_ENSURE_SUCCESS (rv, NS_ERROR_FAILURE);
 
@@ -390,9 +500,42 @@ nsresult EphyBrowser::Init (GtkMozEmbed *mozembed)
 	 * but we cannot get to it!
 	 * See https://bugzilla.mozilla.org/show_bug.cgi?id=94974
 	 */
-	mSecurityInfo = do_CreateInstance(NS_SECURE_BROWSER_UI_CONTRACTID, &rv);
-	NS_ENSURE_TRUE (NS_SUCCEEDED (rv) && mSecurityInfo, NS_ERROR_FAILURE);
-	mSecurityInfo->Init (mDOMWindow);
+	/* First try GI */
+	mSecurityInfo = do_GetInterface (mWebBrowser);
+	/* Try to instantiate it under the re-registered contract ID */
+	if (!mSecurityInfo)
+	{
+		/* This will cause all security warning dialogs to be shown
+		 * twice (once by this instance, and another time by nsWebBrowser's
+		 * instance of nsSecurityBrowserUIImpl), but there appears to be
+		 * no other way :-(
+		 */
+		mSecurityInfo = do_CreateInstance("@gnome.org/project/epiphany/hacks/secure-browser-ui;1", &rv);
+		if (NS_SUCCEEDED (rv) && mSecurityInfo)
+		{
+			rv = mSecurityInfo->Init (mDOMWindow);
+			NS_ENSURE_SUCCESS (rv, rv);
+		}
+	}
+	/* Try the original contract ID */
+	if (!mSecurityInfo)
+	{
+		/* This will cause all security warning dialogs to be shown
+		 * twice (once by this instance, and another time by nsWebBrowser's
+		 * instance of nsSecurityBrowserUIImpl), but there appears to be
+		 * no other way :-(
+		 */
+		mSecurityInfo = do_CreateInstance(NS_SECURE_BROWSER_UI_CONTRACTID, &rv);
+		if (NS_SUCCEEDED (rv) && mSecurityInfo)
+		{
+			rv = mSecurityInfo->Init (mDOMWindow);
+			NS_ENSURE_SUCCESS (rv, rv);
+		}
+	}
+	if (!mSecurityInfo)
+	{
+		g_warning ("Failed to instantiate nsISecureBrowserUI!\n");
+ 	}
 #endif
 
 	mInitialized = PR_TRUE;
@@ -431,6 +574,8 @@ EphyBrowser::AttachListeners(void)
 					     mModalAlertListener, PR_TRUE);
 	rv |= mEventTarget->AddEventListener(nsEmbedString(DOMModalDialogClosed),
 					     mModalAlertListener, PR_TRUE);
+	rv |= mEventTarget->AddEventListener(nsEmbedString(ContextMenu),
+					     mContextMenuListener, PR_TRUE /* capture */);
 	NS_ENSURE_SUCCESS (rv, NS_ERROR_FAILURE);
 
 	return NS_OK;
@@ -450,6 +595,8 @@ EphyBrowser::DetachListeners(void)
 						mModalAlertListener, PR_TRUE);
 	rv |= mEventTarget->RemoveEventListener(nsEmbedString(DOMModalDialogClosed),
 						mModalAlertListener, PR_TRUE);
+	rv |= mEventTarget->RemoveEventListener(nsEmbedString(ContextMenu),
+					        mContextMenuListener, PR_TRUE /* capture */);
 	NS_ENSURE_SUCCESS (rv, NS_ERROR_FAILURE);
 
 	return NS_OK;
