@@ -36,7 +36,7 @@
  *
  * ***** END LICENSE BLOCK *****
  *
- * $Id: EphyHeaderSniffer.cpp,v 1.38 2004/11/02 20:56:55 chpe Exp $
+ * $Id: EphyHeaderSniffer.cpp,v 1.41 2005/01/18 19:33:24 chpe Exp $
  */
 
 #include "mozilla-config.h"
@@ -203,16 +203,17 @@ EphyHeaderSniffer::OnSecurityChange (nsIWebProgress *aWebProgress, nsIRequest *a
 }
 
 static void
-filechooser_response_cb (EphyFileChooser *dialog, gint response, EphyHeaderSniffer* sniffer)
+filechooser_response_cb (GtkWidget *dialog,
+			 gint response,	
+			 EphyHeaderSniffer* sniffer)
 {
 	if (response == GTK_RESPONSE_ACCEPT)
 	{
 		char *filename;
-		GtkWidget *parent = NULL; // FIXME!
 
 		filename = gtk_file_chooser_get_filename (GTK_FILE_CHOOSER (dialog));
 
-		if (ephy_gui_confirm_overwrite_file (parent, filename) == FALSE)
+		if (ephy_gui_confirm_overwrite_file (dialog, filename) == FALSE)
 		{
 			g_free (filename);
 			return;
@@ -237,13 +238,13 @@ filechooser_response_cb (EphyFileChooser *dialog, gint response, EphyHeaderSniff
 nsresult EphyHeaderSniffer::PerformSave (nsIURI* inOriginalURI)
 {
 	nsresult rv;
-	EmbedPersistFlags flags;
+	EphyEmbedPersistFlags flags;
 	PRBool askDownloadDest;
 
 	mOriginalURI = inOriginalURI;
 
 	flags = ephy_embed_persist_get_flags (EPHY_EMBED_PERSIST (mEmbedPersist));
-	askDownloadDest = flags & EMBED_PERSIST_ASK_DESTINATION;
+	askDownloadDest = flags & EPHY_EMBED_PERSIST_ASK_DESTINATION;
 
 	nsEmbedString defaultFileName;
 
