@@ -16,7 +16,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: EphySingle.cpp,v 1.20 2005/01/11 17:36:15 chpe Exp $
+ *  $Id: EphySingle.cpp,v 1.21 2005/01/14 23:54:52 chpe Exp $
  */
 
 #include "mozilla-config.h"
@@ -276,14 +276,6 @@ mozilla_cookie_to_ephy_cookie (nsICookie *cookie)
 	cookie->GetIsSecure (&isSecure);
 	info->is_secure = isSecure != PR_FALSE;
 
-	nsCookieStatus status;
-	cookie->GetStatus (&status);
-	info->p3p_state = (EphyCookieP3PState) status;
-
-	nsCookiePolicy policy;
-	cookie->GetPolicy (&policy);
-	info->p3p_policy = (EphyCookieP3PPolicy) policy;
-
 	PRUint64 dateTime;
 	cookie->GetExpires (&dateTime);
 	info->expires = dateTime;
