@@ -16,7 +16,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: MozRegisterComponents.cpp,v 1.30 2004/11/19 20:13:44 chpe Exp $
+ *  $Id: MozRegisterComponents.cpp,v 1.36 2005/01/24 13:43:58 chpe Exp $
  */
 
 #include "mozilla-config.h"
@@ -27,8 +27,8 @@
 #include "GlobalHistory.h"
 #include "PrintingPromptService.h"
 #include "MozDownload.h"
-#include "EphyAboutRedirector.h"
 #include "EphyContentPolicy.h"
+#include "EphySidebar.h"
 
 #ifdef ENABLE_FILEPICKER
 #include "FilePicker.h"
@@ -38,6 +38,8 @@
 #include "GtkNSSClientAuthDialogs.h"
 #include "GtkNSSDialogs.h"
 #include "GtkNSSKeyPairDialogs.h"
+#include "GtkNSSSecurityWarningDialogs.h"
+#include <nsISecureBrowserUI.h>
 #endif
 
 #include <nsMemory.h>
@@ -51,12 +53,12 @@
 
 #include <glib/gmessages.h>
 
-NS_GENERIC_FACTORY_CONSTRUCTOR(EphyAboutRedirector)
 NS_GENERIC_FACTORY_CONSTRUCTOR(MozDownload)
 NS_GENERIC_FACTORY_CONSTRUCTOR(GContentHandler)
 NS_GENERIC_FACTORY_CONSTRUCTOR(MozGlobalHistory)
 NS_GENERIC_FACTORY_CONSTRUCTOR(GPrintingPromptService)
 NS_GENERIC_FACTORY_CONSTRUCTOR(EphyContentPolicy)
+NS_GENERIC_FACTORY_CONSTRUCTOR(EphySidebar)
 
 #ifdef ENABLE_FILEPICKER
 NS_GENERIC_FACTORY_CONSTRUCTOR(GFilePicker)
@@ -66,6 +68,7 @@ NS_GENERIC_FACTORY_CONSTRUCTOR(GFilePicker)
 NS_GENERIC_FACTORY_CONSTRUCTOR(GtkNSSClientAuthDialogs)
 NS_GENERIC_FACTORY_CONSTRUCTOR(GtkNSSDialogs)
 NS_GENERIC_FACTORY_CONSTRUCTOR(GtkNSSKeyPairDialogs)
+NS_GENERIC_FACTORY_CONSTRUCTOR(GtkNSSSecurityWarningDialogs)
 #endif
  
 static NS_METHOD
@@ -77,12 +80,29 @@ RegisterContentPolicy(nsIComponentManager *aCompMgr, nsIFile *aPath,
 		do_GetService(NS_CATEGORYMANAGER_CONTRACTID);
 	NS_ENSURE_TRUE (cm, NS_ERROR_FAILURE);
 
-	char *oldval;
-	return cm->AddCategoryEntry("content-policy",
-				    EPHY_CONTENT_POLICY_CONTRACTID,
-				    EPHY_CONTENT_POLICY_CONTRACTID,
-				    PR_TRUE, PR_TRUE, &oldval);
-	nsMemory::Free (oldval);
+	nsresult rv;
+	char *oldval = nsnull;
+	rv = cm->AddCategoryEntry ("content-policy",
+				   EPHY_CONTENT_POLICY_CONTRACTID,
+				   EPHY_CONTENT_POLICY_CONTRACTID,
+				   PR_TRUE, PR_TRUE, &oldval);
+	if (oldval)
+		nsMemory::Free (oldval);
+	return rv;
+}
+
+static NS_METHOD
+RegisterSidebar(nsIComponentManager *aCompMgr, nsIFile *aPath,
+                const char *registryLocation, const char *componentType,
+                const nsModuleComponentInfo *info)
+{
+	nsCOMPtr<nsICategoryManager> cm =
+		do_GetService(NS_CATEGORYMANAGER_CONTRACTID);
+	NS_ENSURE_TRUE (cm, NS_ERROR_FAILURE);
+
+	return cm->AddCategoryEntry("JavaScript global property",
+				    "sidebar", NS_SIDEBAR_CONTRACTID,
+				    PR_FALSE, PR_TRUE, nsnull);
 }
 
 static const nsModuleComponentInfo sAppComps[] = {
@@ -125,6 +145,12 @@ static const nsModuleComponentInfo sAppComps[] = {
 		NS_GENERATINGKEYPAIRINFODIALOGS_CONTRACTID,
 		GtkNSSKeyPairDialogsConstructor
 	},
+	{
+		GTK_NSSSECURITYWARNINGDIALOGS_CLASSNAME,
+		GTK_NSSSECURITYWARNINGDIALOGS_CID,
+		NS_SECURITYWARNINGDIALOGS_CONTRACTID,
+		GtkNSSSecurityWarningDialogsConstructor
+	},
 #endif
 	{
 		NS_IHELPERAPPLAUNCHERDLG_CLASSNAME,
@@ -144,24 +170,6 @@ static const nsModuleComponentInfo sAppComps[] = {
 		G_PRINTINGPROMPTSERVICE_CONTRACTID,
 		GPrintingPromptServiceConstructor
 	},
-	{
-		EPHY_ABOUT_REDIRECTOR_CLASSNAME,
-		EPHY_ABOUT_REDIRECTOR_CID,
-		EPHY_ABOUT_REDIRECTOR_EPIPHANY_CONTRACTID,
-		EphyAboutRedirectorConstructor
-	},
-	{
-		EPHY_ABOUT_REDIRECTOR_CLASSNAME,
-		EPHY_ABOUT_REDIRECTOR_CID,
-		EPHY_ABOUT_REDIRECTOR_CONSPIRACY_CONTRACTID,
-		EphyAboutRedirectorConstructor
-	},
-	{
-		EPHY_ABOUT_REDIRECTOR_CLASSNAME,
-		EPHY_ABOUT_REDIRECTOR_CID,
-		EPHY_ABOUT_REDIRECTOR_MARCO_CONTRACTID,
-		EphyAboutRedirectorConstructor
-	},
 	{
 		EPHY_CONTENT_POLICY_CLASSNAME,
 		EPHY_CONTENT_POLICY_CID,
@@ -169,8 +177,51 @@ static const nsModuleComponentInfo sAppComps[] = {
 		EphyContentPolicyConstructor,
 		RegisterContentPolicy
 	},
+	{
+		EPHY_SIDEBAR_CLASSNAME,
+		EPHY_SIDEBAR_CID,
+		NS_SIDEBAR_CONTRACTID,
+		EphySidebarConstructor,
+		RegisterSidebar
+	},
 };
 
+#ifdef HAVE_MOZILLA_PSM
+/* 5999dfd3-571f-4fcf-964b-386879f5cded */
+#define NEW_CID { 0x5999dfd3, 0x571f, 0x4fcf, { 0x96, 0x4b, 0x38, 0x68, 0x79, 0xf5, 0xcd, 0xed } }
+
+static nsresult
+reregister_secure_browser_ui (nsIComponentManager *cm,
+			      nsIComponentRegistrar *cr)
+{
+	NS_ENSURE_ARG (cm);
+	NS_ENSURE_ARG (cr);
+
+	/* Workaround as a result of:
+	 *  https://bugzilla.mozilla.org/show_bug.cgi?id=94974
+	 * see
+	 *  http://bugzilla.gnome.org/show_bug.cgi?id=164670
+	 */
+
+	nsresult rv;
+	nsCOMPtr<nsIFactory> factory;
+	rv = cm->GetClassObjectByContractID (NS_SECURE_BROWSER_UI_CONTRACTID, NS_GET_IID(nsIFactory), getter_AddRefs (factory));
+	NS_ENSURE_SUCCESS (rv, rv);
+
+	nsCID *cidPtr = nsnull;
+	rv = cr->ContractIDToCID(NS_SECURE_BROWSER_UI_CONTRACTID, &cidPtr);
+	NS_ENSURE_TRUE (NS_SUCCEEDED (rv) && cidPtr, rv);
+
+	rv = cr->UnregisterFactory (*cidPtr, factory);
+	NS_ENSURE_SUCCESS (rv, rv);
+
+	const nsCID new_cid = NEW_CID;
+	rv = cr->RegisterFactory (new_cid, "Epiphany Secure Browser Class", "@gnome.org/project/epiphany/hacks/secure-browser-ui;1", factory);
+	nsMemory::Free (cidPtr);
+
+	return rv;
+}
+#endif /* HAVE_MOZILLA_PSM */
 
 gboolean
 mozilla_register_components (void)
@@ -222,5 +273,14 @@ mozilla_register_components (void)
 		}
 	}
 
+#ifdef HAVE_MOZILLA_PSM
+	/* Workaround for http://bugzilla.gnome.org/show_bug.cgi?id=164670 */
+	rv = reregister_secure_browser_ui (cm, cr);
+	if (NS_FAILED (rv))
+	{
+		g_warning ("Failed to divert the nsISecureBrowserUI implementation!\n");
+	}
+#endif /* HAVE_MOZILLA_PSM */
+
 	return ret;
 }
