@@ -16,14 +16,12 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: mozilla-embed-single.cpp,v 1.92.4.4 2004/10/10 16:18:26 marco Exp $
+ *  $Id: mozilla-embed-single.cpp,v 1.105 2004/11/17 20:03:25 chpe Exp $
  */
 
 #include "mozilla-config.h"
 
-#ifdef HAVE_CONFIG_H
 #include "config.h"
-#endif
 
 #include "mozilla-embed-single.h"
 
@@ -51,7 +49,9 @@
 
 #include <nsCOMPtr.h>
 #include <nsMemory.h>
+#define MOZILLA_STRICT_API
 #include <nsEmbedString.h>
+#undef MOZILLA_STRICT_API
 #include <nsIPrefService.h>
 #include <nsIServiceManager.h>
 #include <nsIWindowWatcher.h>
@@ -87,6 +87,8 @@
 #include <nsIIDNService.h>
 #endif
 
+#include <stdlib.h>
+
 #define MOZILLA_PROFILE_DIR  "/mozilla"
 #define MOZILLA_PROFILE_NAME "epiphany"
 #define MOZILLA_PROFILE_FILE "prefs.js"
@@ -119,7 +121,7 @@ mozilla_embed_single_get_type (void)
 {
        static GType type = 0;
 
-        if (type == 0)
+        if (G_UNLIKELY (type == 0))
         {
                 static const GTypeInfo our_info =
                 {
@@ -399,6 +401,7 @@ have_gnome_url_handler (const gchar *protocol)
 	return rv;
 }
 
+#if defined(MOZ_NSIXULCHROMEREGISTRY_SELECTSKIN) || defined(HAVE_CHROME_NSICHROMEREGISTRYSEA_H)
 static nsresult
 getUILang (nsAString& aUILang)
 {
@@ -421,6 +424,7 @@ getUILang (nsAString& aUILang)
 
 	return NS_OK;
 }
+#endif
 
 static nsresult
 mozilla_init_chrome (void)
@@ -504,7 +508,7 @@ init_services (MozillaEmbedSingle *single)
 	mozilla_setup_colors (single);
 
 	START_PROFILER ("Mozilla prefs notifiers")
-	mozilla_notifiers_init (EPHY_EMBED_SINGLE (single));
+	mozilla_notifiers_init ();
 	STOP_PROFILER ("Mozilla prefs notifiers")
 
 	mozilla_register_components ();
@@ -519,7 +523,6 @@ mozilla_embed_single_init (MozillaEmbedSingle *mes)
 {
  	mes->priv = MOZILLA_EMBED_SINGLE_GET_PRIVATE (mes);
 
-	mes->priv->theme_window = NULL;
 	mes->priv->user_prefs =
 		g_build_filename (ephy_dot_dir (), 
 				  MOZILLA_PROFILE_DIR,
@@ -527,22 +530,17 @@ mozilla_embed_single_init (MozillaEmbedSingle *mes)
 				  MOZILLA_PROFILE_FILE,
 				  NULL);
 
-	mes->priv->mSingleObserver = nsnull;
-
 	if (!init_services (mes))
 	{
 		GtkWidget *dialog;
 
-		/* FIXME Kill references to MOZILLA_FIVE_HOME
-		   when string freeze is over */
 		dialog = gtk_message_dialog_new
 			(NULL,
                          GTK_DIALOG_MODAL,
                          GTK_MESSAGE_ERROR,
                          GTK_BUTTONS_CLOSE,
                          _("Epiphany can't be used now. "
-                         "Mozilla initialization failed. Check your "
-                         "MOZILLA_FIVE_HOME environmental variable."));
+                         "Mozilla initialization failed."));
 		gtk_dialog_run (GTK_DIALOG (dialog));
 
 		exit (0);
@@ -560,6 +558,8 @@ mozilla_embed_single_dispose (GObject *object)
 		NS_RELEASE (single->priv->mSingleObserver);
 		single->priv->mSingleObserver = nsnull;
 	}
+
+	parent_class->dispose (object);
 }
 
 static void
@@ -571,7 +571,7 @@ mozilla_embed_single_finalize (GObject *object)
 	 * services depend on xpcom */
 	G_OBJECT_CLASS (parent_class)->finalize (object);
 
-	mozilla_notifiers_free ();
+	mozilla_notifiers_shutdown ();
 
 	gtk_moz_embed_pop_startup ();
 
