@@ -16,7 +16,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: mozilla-embed.cpp,v 1.91 2004/11/17 19:39:37 chpe Exp $
+ *  $Id: mozilla-embed.cpp,v 1.97 2005/01/23 15:38:02 chpe Exp $
  */
 
 #include "mozilla-config.h"
@@ -57,9 +57,6 @@ static void mozilla_embed_net_state_all_cb	(GtkMozEmbed *embed,
 						 gint state,
 						 guint status,
 						 MozillaEmbed *membed);
-static gint mozilla_embed_dom_key_down_cb	(GtkMozEmbed *embed,
-						 gpointer dom_event,
-						 MozillaEmbed *membed);
 static gint mozilla_embed_dom_mouse_click_cb	(GtkMozEmbed *embed,
 						 gpointer dom_event,
 						 MozillaEmbed *membed);
@@ -74,7 +71,7 @@ static void mozilla_embed_security_change_cb	(GtkMozEmbed *embed,
 						 gpointer request,
 						 PRUint32 state,
 						 MozillaEmbed *membed);
-static EmbedSecurityLevel mozilla_embed_security_level (PRUint32 state);
+static EphyEmbedSecurityLevel mozilla_embed_security_level (PRUint32 state);
 
 #define MOZILLA_EMBED_GET_PRIVATE(object)(G_TYPE_INSTANCE_GET_PRIVATE ((object), MOZILLA_TYPE_EMBED, MozillaEmbedPrivate))
 
@@ -279,9 +276,6 @@ mozilla_embed_init (MozillaEmbed *embed)
 	g_signal_connect_object (G_OBJECT (embed), "security_change",
 				 G_CALLBACK (mozilla_embed_security_change_cb),
 				 embed, (GConnectFlags) 0);
-	g_signal_connect_object (G_OBJECT (embed), "dom_key_down",
-				 G_CALLBACK (mozilla_embed_dom_key_down_cb),
-				 embed, (GConnectFlags) 0);
 }
 
 gpointer
@@ -632,12 +626,12 @@ impl_shistory_go_nth (EphyEmbed *embed,
 
 static void
 impl_get_security_level (EphyEmbed *embed,
-                         EmbedSecurityLevel *level,
+                         EphyEmbedSecurityLevel *level,
                          char **description)
 {
 	MozillaEmbedPrivate *mpriv = MOZILLA_EMBED (embed)->priv;
 
-	if (level) *level = STATE_IS_UNKNOWN;
+	if (level) *level = EPHY_EMBED_STATE_IS_UNKNOWN;
 	if (description) *description = NULL;
 
 	nsresult rv;
@@ -688,7 +682,7 @@ impl_print_preview_n_pages (EphyEmbed *embed)
 
 static void
 impl_print_preview_navigate (EphyEmbed *embed,
-			     EmbedPrintPreviewNavType type,
+			     EphyEmbedPrintPreviewNavType type,
 			     int page)
 {
 	MozillaEmbedPrivate *mpriv = MOZILLA_EMBED(embed)->priv;
@@ -789,6 +783,13 @@ update_load_state (MozillaEmbed *membed, gint state)
 {
 	MozillaEmbedPrivate *priv = membed->priv;
 
+	if (state & GTK_MOZ_EMBED_FLAG_IS_DOCUMENT &&
+	    state & (GTK_MOZ_EMBED_FLAG_START | GTK_MOZ_EMBED_FLAG_STOP))
+	{
+		g_signal_emit_by_name (membed, "ge-document-type",
+				       priv->browser->GetDocumentType ());
+	}
+
 	if (state & GTK_MOZ_EMBED_FLAG_IS_NETWORK)
 	{
 		if (state & GTK_MOZ_EMBED_FLAG_START)
@@ -829,32 +830,32 @@ mozilla_embed_net_state_all_cb (GtkMozEmbed *embed, const char *aURI,
                                 gint state, guint status, 
 				MozillaEmbed *membed)
 {
-	EmbedState estate = EMBED_STATE_UNKNOWN;
+	EphyEmbedNetState estate = EPHY_EMBED_STATE_UNKNOWN;
 	int i;
 
 	struct
 	{
 		guint state;
-		EmbedState embed_state;
+		EphyEmbedNetState embed_state;
 	}
 	conversion_map [] =
 	{
-		{ GTK_MOZ_EMBED_FLAG_START, EMBED_STATE_START },
-		{ GTK_MOZ_EMBED_FLAG_STOP, EMBED_STATE_STOP },
-		{ GTK_MOZ_EMBED_FLAG_REDIRECTING, EMBED_STATE_REDIRECTING },
-		{ GTK_MOZ_EMBED_FLAG_TRANSFERRING, EMBED_STATE_TRANSFERRING },
-		{ GTK_MOZ_EMBED_FLAG_NEGOTIATING, EMBED_STATE_NEGOTIATING },
-		{ GTK_MOZ_EMBED_FLAG_IS_REQUEST, EMBED_STATE_IS_REQUEST },
-		{ GTK_MOZ_EMBED_FLAG_IS_DOCUMENT, EMBED_STATE_IS_DOCUMENT },
-		{ GTK_MOZ_EMBED_FLAG_IS_NETWORK, EMBED_STATE_IS_NETWORK },
-		{ 0, EMBED_STATE_UNKNOWN }
+		{ GTK_MOZ_EMBED_FLAG_START, EPHY_EMBED_STATE_START },
+		{ GTK_MOZ_EMBED_FLAG_STOP, EPHY_EMBED_STATE_STOP },
+		{ GTK_MOZ_EMBED_FLAG_REDIRECTING, EPHY_EMBED_STATE_REDIRECTING },
+		{ GTK_MOZ_EMBED_FLAG_TRANSFERRING, EPHY_EMBED_STATE_TRANSFERRING },
+		{ GTK_MOZ_EMBED_FLAG_NEGOTIATING, EPHY_EMBED_STATE_NEGOTIATING },
+		{ GTK_MOZ_EMBED_FLAG_IS_REQUEST, EPHY_EMBED_STATE_IS_REQUEST },
+		{ GTK_MOZ_EMBED_FLAG_IS_DOCUMENT, EPHY_EMBED_STATE_IS_DOCUMENT },
+		{ GTK_MOZ_EMBED_FLAG_IS_NETWORK, EPHY_EMBED_STATE_IS_NETWORK },
+		{ 0, EPHY_EMBED_STATE_UNKNOWN }
 	};
 
 	for (i = 0; conversion_map[i].state != 0; i++)
 	{
 		if (state & conversion_map[i].state)
 		{
-			estate = (EmbedState) (estate | conversion_map[i].embed_state);	
+			estate = (EphyEmbedNetState) (estate | conversion_map[i].embed_state);	
 		}
 	}
 
@@ -863,71 +864,6 @@ mozilla_embed_net_state_all_cb (GtkMozEmbed *embed, const char *aURI,
 	g_signal_emit_by_name (membed, "ge_net_state", aURI, estate);
 }
 
-static gint
-mozilla_embed_dom_key_down_cb (GtkMozEmbed *embed, gpointer dom_event,
-		               MozillaEmbed *membed)
-{
-	MozillaEmbedPrivate *mpriv = MOZILLA_EMBED(embed)->priv;
-
-	if (dom_event == NULL)
-	{
-		g_warning ("mozilla_embed_dom_key_down_cb: domevent NULL");
-		return FALSE;
-	}
-
-	nsCOMPtr<nsIDOMKeyEvent> ev = static_cast<nsIDOMKeyEvent*>(dom_event);
-	NS_ENSURE_TRUE (ev, FALSE);
-	nsCOMPtr<nsIDOMEvent> dev = do_QueryInterface (ev);
-	NS_ENSURE_TRUE (dev, FALSE);
-
-	MozillaEmbedEvent *info;
-	info = mozilla_embed_event_new (NS_STATIC_CAST (gpointer, dev));
-
-	gboolean ret = FALSE;
-
-	nsresult rv;
-	EventContext ctx;
-	ctx.Init (mpriv->browser);
-	rv = ctx.GetKeyEventInfo (ev, info);
-	if (NS_FAILED (rv)) return ret;
-
-	if ((info->keycode == nsIDOMKeyEvent::DOM_VK_F10 &&
-	    (info->modifier == GDK_SHIFT_MASK ||
-	     info->modifier == GDK_CONTROL_MASK))
-	    || (info->keycode == nsIDOMKeyEvent::DOM_VK_CONTEXT_MENU &&
-		!info->modifier)
-	   )
-	{
-		/* Translate relative coordinates to absolute values, and try
-		   to avoid covering links by adding a little offset. */
-
-		int x, y;
-		gdk_window_get_origin (GTK_WIDGET(membed)->window, &x, &y);
-		info->x += x + 6;	
-		info->y += y + 6;
-
-		if (info->modifier == GDK_CONTROL_MASK)
-		{
-			info->context = EMBED_CONTEXT_DOCUMENT;	
-		}
-
-		nsCOMPtr<nsIDOMDocument> doc;
-		rv = ctx.GetTargetDocument (getter_AddRefs(doc));
-		if (NS_SUCCEEDED(rv))
-		{
-			rv = mpriv->browser->PushTargetDocument (doc);
-			if (NS_SUCCEEDED(rv))
-			{
-				g_signal_emit_by_name (membed, "ge_context_menu", info, &ret);
-				mpriv->browser->PopTargetDocument ();
-			}
-		}
-	}
-
-	g_object_unref (info);
-	return ret;
-}
-
 static gint
 mozilla_embed_dom_mouse_click_cb (GtkMozEmbed *embed, gpointer dom_event, 
 				  MozillaEmbed *membed)
@@ -984,7 +920,6 @@ mozilla_embed_dom_mouse_down_cb (GtkMozEmbed *embed, gpointer dom_event,
 	EventContext event_context;
 	gint return_value = FALSE;
 	nsresult rv;
-	EphyEmbedEventType type;
 	MozillaEmbedPrivate *mpriv = MOZILLA_EMBED(embed)->priv;
 
 	if (dom_event == NULL)
@@ -1004,28 +939,16 @@ mozilla_embed_dom_mouse_down_cb (GtkMozEmbed *embed, gpointer dom_event,
         rv = event_context.GetMouseEventInfo (ev, MOZILLA_EMBED_EVENT (info));
 	if (NS_FAILED (rv)) return FALSE;
 
-	type = ephy_embed_event_get_event_type ((EphyEmbedEvent *) info);
-		
 	nsCOMPtr<nsIDOMDocument> domDoc;
 	rv = event_context.GetTargetDocument (getter_AddRefs(domDoc));
 	if (NS_SUCCEEDED (rv))
 	{
-		rv = mpriv->browser->PushTargetDocument (domDoc);
+		mpriv->browser->PushTargetDocument (domDoc);
 
-		if (NS_SUCCEEDED (rv))
-		{
-			g_signal_emit_by_name (membed, "ge_dom_mouse_down", 
-					       info, &return_value); 
+		g_signal_emit_by_name (membed, "ge_dom_mouse_down", 
+				       info, &return_value); 
 
-			if (return_value == FALSE &&
-			    type == EPHY_EMBED_EVENT_MOUSE_BUTTON3)
-			{
-				g_signal_emit_by_name (membed, "ge_context_menu", 
-						       info, &return_value);
-			}
-
-			mpriv->browser->PopTargetDocument ();
-		}
+		mpriv->browser->PopTargetDocument ();
 	}
 
 	g_object_unref (info);
@@ -1071,11 +994,13 @@ mozilla_embed_new_window_cb (GtkMozEmbed *embed,
 		}
 	}
 
-	g_signal_emit_by_name (membed, "ge_new_window", &new_embed, mask);
+	g_signal_emit_by_name (membed, "ge_new_window", mask, &new_embed);
 
 	g_assert (new_embed != NULL);
-	
-	*newEmbed = GTK_MOZ_EMBED(new_embed);
+
+	gtk_moz_embed_set_chrome_mask (GTK_MOZ_EMBED (new_embed), chrome_mask);
+
+	*newEmbed = GTK_MOZ_EMBED (new_embed);
 }
 
 static void
@@ -1088,33 +1013,33 @@ mozilla_embed_security_change_cb (GtkMozEmbed *embed,
 			       mozilla_embed_security_level (state));
 }
 
-static EmbedSecurityLevel
+static EphyEmbedSecurityLevel
 mozilla_embed_security_level (PRUint32 state)
 {
-	EmbedSecurityLevel level;
+	EphyEmbedSecurityLevel level;
 
 	switch (state)
         {
         case nsIWebProgressListener::STATE_IS_INSECURE:
-                level = STATE_IS_INSECURE;
+                level = EPHY_EMBED_STATE_IS_INSECURE;
                 break;
         case nsIWebProgressListener::STATE_IS_BROKEN:
-                level = STATE_IS_BROKEN;
+                level = EPHY_EMBED_STATE_IS_BROKEN;
                 break;
         case nsIWebProgressListener::STATE_IS_SECURE|
              nsIWebProgressListener::STATE_SECURE_HIGH:
-                level = STATE_IS_SECURE_HIGH;
+                level = EPHY_EMBED_STATE_IS_SECURE_HIGH;
                 break;
         case nsIWebProgressListener::STATE_IS_SECURE|
              nsIWebProgressListener::STATE_SECURE_MED:
-                level = STATE_IS_SECURE_MED;
+                level = EPHY_EMBED_STATE_IS_SECURE_MED;
                 break;
         case nsIWebProgressListener::STATE_IS_SECURE|
              nsIWebProgressListener::STATE_SECURE_LOW:
-                level = STATE_IS_SECURE_LOW;
+                level = EPHY_EMBED_STATE_IS_SECURE_LOW;
                 break;
         default:
-                level = STATE_IS_UNKNOWN;
+                level = EPHY_EMBED_STATE_IS_UNKNOWN;
                 break;
         }
 	return level;
