@@ -16,7 +16,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-dialog.c,v 1.46 2004/11/02 20:57:20 chpe Exp $
+ *  $Id: ephy-dialog.c,v 1.49 2005/01/18 19:28:14 chpe Exp $
  */
 
 #include "config.h"
@@ -74,7 +74,7 @@ typedef struct
 
 #define EPHY_DIALOG_GET_PRIVATE(object)(G_TYPE_INSTANCE_GET_PRIVATE ((object), EPHY_TYPE_DIALOG, EphyDialogPrivate))
 
-struct EphyDialogPrivate
+struct _EphyDialogPrivate
 {
 	char *name;
 
@@ -1178,6 +1178,8 @@ ephy_dialog_set_size_group (EphyDialog *dialog,
 	}
 
 	va_end (vl);
+
+	g_object_unref (size_group);
 }
 
 void
@@ -1212,6 +1214,9 @@ ephy_dialog_run (EphyDialog *dialog)
 {
 	ephy_dialog_show (dialog);
 
+	gtk_window_group_add_window (ephy_gui_ensure_window_group (GTK_WINDOW (dialog->priv->parent)),
+				     GTK_WINDOW (dialog->priv->dialog));
+
 	return gtk_dialog_run (GTK_DIALOG (dialog->priv->dialog));
 }
 
