@@ -51,31 +51,34 @@ G_BEGIN_DECLS
 #endif /* !G_ENABLE_DEBUG */
 
 
-/* INT:STRING (../../lib/ephy-marshal.list:1) */
-extern void ephy_marshal_INT__STRING (GClosure     *closure,
-                                      GValue       *return_value,
-                                      guint         n_param_values,
-                                      const GValue *param_values,
-                                      gpointer      invocation_hint,
-                                      gpointer      marshal_data);
+/* BOOLEAN:ENUM,STRING,STRING,STRING (../../lib/ephy-marshal.list:1) */
+extern void ephy_marshal_BOOLEAN__ENUM_STRING_STRING_STRING (GClosure     *closure,
+                                                             GValue       *return_value,
+                                                             guint         n_param_values,
+                                                             const GValue *param_values,
+                                                             gpointer      invocation_hint,
+                                                             gpointer      marshal_data);
 void
-ephy_marshal_INT__STRING (GClosure     *closure,
-                          GValue       *return_value,
-                          guint         n_param_values,
-                          const GValue *param_values,
-                          gpointer      invocation_hint,
-                          gpointer      marshal_data)
+ephy_marshal_BOOLEAN__ENUM_STRING_STRING_STRING (GClosure     *closure,
+                                                 GValue       *return_value,
+                                                 guint         n_param_values,
+                                                 const GValue *param_values,
+                                                 gpointer      invocation_hint,
+                                                 gpointer      marshal_data)
 {
-  typedef gint (*GMarshalFunc_INT__STRING) (gpointer     data1,
-                                            gpointer     arg_1,
-                                            gpointer     data2);
-  register GMarshalFunc_INT__STRING callback;
+  typedef gboolean (*GMarshalFunc_BOOLEAN__ENUM_STRING_STRING_STRING) (gpointer     data1,
+                                                                       gint         arg_1,
+                                                                       gpointer     arg_2,
+                                                                       gpointer     arg_3,
+                                                                       gpointer     arg_4,
+                                                                       gpointer     data2);
+  register GMarshalFunc_BOOLEAN__ENUM_STRING_STRING_STRING callback;
   register GCClosure *cc = (GCClosure*) closure;
   register gpointer data1, data2;
-  gint v_return;
+  gboolean v_return;
 
   g_return_if_fail (return_value != NULL);
-  g_return_if_fail (n_param_values == 2);
+  g_return_if_fail (n_param_values == 5);
 
   if (G_CCLOSURE_SWAP_DATA (closure))
     {
@@ -87,13 +90,16 @@ ephy_marshal_INT__STRING (GClosure     *closure,
       data1 = g_value_peek_pointer (param_values + 0);
       data2 = closure->data;
     }
-  callback = (GMarshalFunc_INT__STRING) (marshal_data ? marshal_data : cc->callback);
+  callback = (GMarshalFunc_BOOLEAN__ENUM_STRING_STRING_STRING) (marshal_data ? marshal_data : cc->callback);
 
   v_return = callback (data1,
-                       g_marshal_value_peek_string (param_values + 1),
+                       g_marshal_value_peek_enum (param_values + 1),
+                       g_marshal_value_peek_string (param_values + 2),
+                       g_marshal_value_peek_string (param_values + 3),
+                       g_marshal_value_peek_string (param_values + 4),
                        data2);
 
-  g_value_set_int (return_value, v_return);
+  g_value_set_boolean (return_value, v_return);
 }
 
 /* BOOLEAN:OBJECT (../../lib/ephy-marshal.list:2) */
@@ -231,30 +237,77 @@ ephy_marshal_BOOLEAN__VOID (GClosure     *closure,
   g_value_set_boolean (return_value, v_return);
 }
 
-/* VOID:ENUM,INT,BOOLEAN (../../lib/ephy-marshal.list:5) */
-extern void ephy_marshal_VOID__ENUM_INT_BOOLEAN (GClosure     *closure,
-                                                 GValue       *return_value,
-                                                 guint         n_param_values,
-                                                 const GValue *param_values,
-                                                 gpointer      invocation_hint,
-                                                 gpointer      marshal_data);
+/* OBJECT:FLAGS (../../lib/ephy-marshal.list:5) */
+extern void ephy_marshal_OBJECT__FLAGS (GClosure     *closure,
+                                        GValue       *return_value,
+                                        guint         n_param_values,
+                                        const GValue *param_values,
+                                        gpointer      invocation_hint,
+                                        gpointer      marshal_data);
 void
-ephy_marshal_VOID__ENUM_INT_BOOLEAN (GClosure     *closure,
-                                     GValue       *return_value,
-                                     guint         n_param_values,
-                                     const GValue *param_values,
-                                     gpointer      invocation_hint,
-                                     gpointer      marshal_data)
+ephy_marshal_OBJECT__FLAGS (GClosure     *closure,
+                            GValue       *return_value,
+                            guint         n_param_values,
+                            const GValue *param_values,
+                            gpointer      invocation_hint,
+                            gpointer      marshal_data)
 {
-  typedef void (*GMarshalFunc_VOID__ENUM_INT_BOOLEAN) (gpointer     data1,
-                                                       gint         arg_1,
-                                                       gint         arg_2,
-                                                       gboolean     arg_3,
-                                                       gpointer     data2);
-  register GMarshalFunc_VOID__ENUM_INT_BOOLEAN callback;
+  typedef GObject* (*GMarshalFunc_OBJECT__FLAGS) (gpointer     data1,
+                                                  guint        arg_1,
+                                                  gpointer     data2);
+  register GMarshalFunc_OBJECT__FLAGS callback;
   register GCClosure *cc = (GCClosure*) closure;
   register gpointer data1, data2;
+  GObject* v_return;
 
+  g_return_if_fail (return_value != NULL);
+  g_return_if_fail (n_param_values == 2);
+
+  if (G_CCLOSURE_SWAP_DATA (closure))
+    {
+      data1 = closure->data;
+      data2 = g_value_peek_pointer (param_values + 0);
+    }
+  else
+    {
+      data1 = g_value_peek_pointer (param_values + 0);
+      data2 = closure->data;
+    }
+  callback = (GMarshalFunc_OBJECT__FLAGS) (marshal_data ? marshal_data : cc->callback);
+
+  v_return = callback (data1,
+                       g_marshal_value_peek_flags (param_values + 1),
+                       data2);
+
+  g_value_take_object (return_value, v_return);
+}
+
+/* OBJECT:STRING,OBJECT,FLAGS (../../lib/ephy-marshal.list:6) */
+extern void ephy_marshal_OBJECT__STRING_OBJECT_FLAGS (GClosure     *closure,
+                                                      GValue       *return_value,
+                                                      guint         n_param_values,
+                                                      const GValue *param_values,
+                                                      gpointer      invocation_hint,
+                                                      gpointer      marshal_data);
+void
+ephy_marshal_OBJECT__STRING_OBJECT_FLAGS (GClosure     *closure,
+                                          GValue       *return_value,
+                                          guint         n_param_values,
+                                          const GValue *param_values,
+                                          gpointer      invocation_hint,
+                                          gpointer      marshal_data)
+{
+  typedef GObject* (*GMarshalFunc_OBJECT__STRING_OBJECT_FLAGS) (gpointer     data1,
+                                                                gpointer     arg_1,
+                                                                gpointer     arg_2,
+                                                                guint        arg_3,
+                                                                gpointer     data2);
+  register GMarshalFunc_OBJECT__STRING_OBJECT_FLAGS callback;
+  register GCClosure *cc = (GCClosure*) closure;
+  register gpointer data1, data2;
+  GObject* v_return;
+
+  g_return_if_fail (return_value != NULL);
   g_return_if_fail (n_param_values == 4);
 
   if (G_CCLOSURE_SWAP_DATA (closure))
@@ -267,39 +320,41 @@ ephy_marshal_VOID__ENUM_INT_BOOLEAN (GClosure     *closure,
       data1 = g_value_peek_pointer (param_values + 0);
       data2 = closure->data;
     }
-  callback = (GMarshalFunc_VOID__ENUM_INT_BOOLEAN) (marshal_data ? marshal_data : cc->callback);
+  callback = (GMarshalFunc_OBJECT__STRING_OBJECT_FLAGS) (marshal_data ? marshal_data : cc->callback);
 
-  callback (data1,
-            g_marshal_value_peek_enum (param_values + 1),
-            g_marshal_value_peek_int (param_values + 2),
-            g_marshal_value_peek_boolean (param_values + 3),
-            data2);
+  v_return = callback (data1,
+                       g_marshal_value_peek_string (param_values + 1),
+                       g_marshal_value_peek_object (param_values + 2),
+                       g_marshal_value_peek_flags (param_values + 3),
+                       data2);
+
+  g_value_take_object (return_value, v_return);
 }
 
-/* VOID:INT,INT (../../lib/ephy-marshal.list:6) */
-extern void ephy_marshal_VOID__INT_INT (GClosure     *closure,
-                                        GValue       *return_value,
-                                        guint         n_param_values,
-                                        const GValue *param_values,
-                                        gpointer      invocation_hint,
-                                        gpointer      marshal_data);
+/* STRING:VOID (../../lib/ephy-marshal.list:7) */
+extern void ephy_marshal_STRING__VOID (GClosure     *closure,
+                                       GValue       *return_value,
+                                       guint         n_param_values,
+                                       const GValue *param_values,
+                                       gpointer      invocation_hint,
+                                       gpointer      marshal_data);
 void
-ephy_marshal_VOID__INT_INT (GClosure     *closure,
-                            GValue       *return_value,
-                            guint         n_param_values,
-                            const GValue *param_values,
-                            gpointer      invocation_hint,
-                            gpointer      marshal_data)
+ephy_marshal_STRING__VOID (GClosure     *closure,
+                           GValue       *return_value,
+                           guint         n_param_values,
+                           const GValue *param_values,
+                           gpointer      invocation_hint,
+                           gpointer      marshal_data)
 {
-  typedef void (*GMarshalFunc_VOID__INT_INT) (gpointer     data1,
-                                              gint         arg_1,
-                                              gint         arg_2,
-                                              gpointer     data2);
-  register GMarshalFunc_VOID__INT_INT callback;
+  typedef gchar* (*GMarshalFunc_STRING__VOID) (gpointer     data1,
+                                               gpointer     data2);
+  register GMarshalFunc_STRING__VOID callback;
   register GCClosure *cc = (GCClosure*) closure;
   register gpointer data1, data2;
+  gchar* v_return;
 
-  g_return_if_fail (n_param_values == 3);
+  g_return_if_fail (return_value != NULL);
+  g_return_if_fail (n_param_values == 1);
 
   if (G_CCLOSURE_SWAP_DATA (closure))
     {
@@ -311,58 +366,18 @@ ephy_marshal_VOID__INT_INT (GClosure     *closure,
       data1 = g_value_peek_pointer (param_values + 0);
       data2 = closure->data;
     }
-  callback = (GMarshalFunc_VOID__INT_INT) (marshal_data ? marshal_data : cc->callback);
+  callback = (GMarshalFunc_STRING__VOID) (marshal_data ? marshal_data : cc->callback);
 
-  callback (data1,
-            g_marshal_value_peek_int (param_values + 1),
-            g_marshal_value_peek_int (param_values + 2),
-            data2);
+  v_return = callback (data1,
+                       data2);
+
+  g_value_take_string (return_value, v_return);
 }
 
-/* VOID:POINTER,INT (../../lib/ephy-marshal.list:7) */
-extern void ephy_marshal_VOID__POINTER_INT (GClosure     *closure,
-                                            GValue       *return_value,
-                                            guint         n_param_values,
-                                            const GValue *param_values,
-                                            gpointer      invocation_hint,
-                                            gpointer      marshal_data);
-void
-ephy_marshal_VOID__POINTER_INT (GClosure     *closure,
-                                GValue       *return_value,
-                                guint         n_param_values,
-                                const GValue *param_values,
-                                gpointer      invocation_hint,
-                                gpointer      marshal_data)
-{
-  typedef void (*GMarshalFunc_VOID__POINTER_INT) (gpointer     data1,
-                                                  gpointer     arg_1,
-                                                  gint         arg_2,
-                                                  gpointer     data2);
-  register GMarshalFunc_VOID__POINTER_INT callback;
-  register GCClosure *cc = (GCClosure*) closure;
-  register gpointer data1, data2;
+/* VOID:ENUM (../../lib/ephy-marshal.list:8) */
+#define ephy_marshal_VOID__ENUM	g_cclosure_marshal_VOID__ENUM
 
-  g_return_if_fail (n_param_values == 3);
-
-  if (G_CCLOSURE_SWAP_DATA (closure))
-    {
-      data1 = closure->data;
-      data2 = g_value_peek_pointer (param_values + 0);
-    }
-  else
-    {
-      data1 = g_value_peek_pointer (param_values + 0);
-      data2 = closure->data;
-    }
-  callback = (GMarshalFunc_VOID__POINTER_INT) (marshal_data ? marshal_data : cc->callback);
-
-  callback (data1,
-            g_marshal_value_peek_pointer (param_values + 1),
-            g_marshal_value_peek_int (param_values + 2),
-            data2);
-}
-
-/* VOID:POINTER,BOOLEAN (../../lib/ephy-marshal.list:8) */
+/* VOID:POINTER,BOOLEAN (../../lib/ephy-marshal.list:9) */
 extern void ephy_marshal_VOID__POINTER_BOOLEAN (GClosure     *closure,
                                                 GValue       *return_value,
                                                 guint         n_param_values,
@@ -405,7 +420,7 @@ ephy_marshal_VOID__POINTER_BOOLEAN (GClosure     *closure,
             data2);
 }
 
-/* VOID:POINTER,POINTER (../../lib/ephy-marshal.list:9) */
+/* VOID:POINTER,POINTER (../../lib/ephy-marshal.list:10) */
 extern void ephy_marshal_VOID__POINTER_POINTER (GClosure     *closure,
                                                 GValue       *return_value,
                                                 guint         n_param_values,
@@ -448,7 +463,50 @@ ephy_marshal_VOID__POINTER_POINTER (GClosure     *closure,
             data2);
 }
 
-/* VOID:STRING,INT (../../lib/ephy-marshal.list:10) */
+/* VOID:STRING,FLAGS (../../lib/ephy-marshal.list:11) */
+extern void ephy_marshal_VOID__STRING_FLAGS (GClosure     *closure,
+                                             GValue       *return_value,
+                                             guint         n_param_values,
+                                             const GValue *param_values,
+                                             gpointer      invocation_hint,
+                                             gpointer      marshal_data);
+void
+ephy_marshal_VOID__STRING_FLAGS (GClosure     *closure,
+                                 GValue       *return_value,
+                                 guint         n_param_values,
+                                 const GValue *param_values,
+                                 gpointer      invocation_hint,
+                                 gpointer      marshal_data)
+{
+  typedef void (*GMarshalFunc_VOID__STRING_FLAGS) (gpointer     data1,
+                                                   gpointer     arg_1,
+                                                   guint        arg_2,
+                                                   gpointer     data2);
+  register GMarshalFunc_VOID__STRING_FLAGS callback;
+  register GCClosure *cc = (GCClosure*) closure;
+  register gpointer data1, data2;
+
+  g_return_if_fail (n_param_values == 3);
+
+  if (G_CCLOSURE_SWAP_DATA (closure))
+    {
+      data1 = closure->data;
+      data2 = g_value_peek_pointer (param_values + 0);
+    }
+  else
+    {
+      data1 = g_value_peek_pointer (param_values + 0);
+      data2 = closure->data;
+    }
+  callback = (GMarshalFunc_VOID__STRING_FLAGS) (marshal_data ? marshal_data : cc->callback);
+
+  callback (data1,
+            g_marshal_value_peek_string (param_values + 1),
+            g_marshal_value_peek_flags (param_values + 2),
+            data2);
+}
+
+/* VOID:STRING,INT (../../lib/ephy-marshal.list:12) */
 extern void ephy_marshal_VOID__STRING_INT (GClosure     *closure,
                                            GValue       *return_value,
                                            guint         n_param_values,
@@ -491,52 +549,7 @@ ephy_marshal_VOID__STRING_INT (GClosure     *closure,
             data2);
 }
 
-/* VOID:STRING,INT,INT (../../lib/ephy-marshal.list:11) */
-extern void ephy_marshal_VOID__STRING_INT_INT (GClosure     *closure,
-                                               GValue       *return_value,
-                                               guint         n_param_values,
-                                               const GValue *param_values,
-                                               gpointer      invocation_hint,
-                                               gpointer      marshal_data);
-void
-ephy_marshal_VOID__STRING_INT_INT (GClosure     *closure,
-                                   GValue       *return_value,
-                                   guint         n_param_values,
-                                   const GValue *param_values,
-                                   gpointer      invocation_hint,
-                                   gpointer      marshal_data)
-{
-  typedef void (*GMarshalFunc_VOID__STRING_INT_INT) (gpointer     data1,
-                                                     gpointer     arg_1,
-                                                     gint         arg_2,
-                                                     gint         arg_3,
-                                                     gpointer     data2);
-  register GMarshalFunc_VOID__STRING_INT_INT callback;
-  register GCClosure *cc = (GCClosure*) closure;
-  register gpointer data1, data2;
-
-  g_return_if_fail (n_param_values == 4);
-
-  if (G_CCLOSURE_SWAP_DATA (closure))
-    {
-      data1 = closure->data;
-      data2 = g_value_peek_pointer (param_values + 0);
-    }
-  else
-    {
-      data1 = g_value_peek_pointer (param_values + 0);
-      data2 = closure->data;
-    }
-  callback = (GMarshalFunc_VOID__STRING_INT_INT) (marshal_data ? marshal_data : cc->callback);
-
-  callback (data1,
-            g_marshal_value_peek_string (param_values + 1),
-            g_marshal_value_peek_int (param_values + 2),
-            g_marshal_value_peek_int (param_values + 3),
-            data2);
-}
-
-/* VOID:STRING,STRING (../../lib/ephy-marshal.list:12) */
+/* VOID:STRING,STRING (../../lib/ephy-marshal.list:13) */
 extern void ephy_marshal_VOID__STRING_STRING (GClosure     *closure,
                                               GValue       *return_value,
                                               guint         n_param_values,
@@ -579,49 +592,6 @@ ephy_marshal_VOID__STRING_STRING (GClosure     *closure,
             data2);
 }
 
-/* VOID:STRING,BOOLEAN (../../lib/ephy-marshal.list:13) */
-extern void ephy_marshal_VOID__STRING_BOOLEAN (GClosure     *closure,
-                                               GValue       *return_value,
-                                               guint         n_param_values,
-                                               const GValue *param_values,
-                                               gpointer      invocation_hint,
-                                               gpointer      marshal_data);
-void
-ephy_marshal_VOID__STRING_BOOLEAN (GClosure     *closure,
-                                   GValue       *return_value,
-                                   guint         n_param_values,
-                                   const GValue *param_values,
-                                   gpointer      invocation_hint,
-                                   gpointer      marshal_data)
-{
-  typedef void (*GMarshalFunc_VOID__STRING_BOOLEAN) (gpointer     data1,
-                                                     gpointer     arg_1,
-                                                     gboolean     arg_2,
-                                                     gpointer     data2);
-  register GMarshalFunc_VOID__STRING_BOOLEAN callback;
-  register GCClosure *cc = (GCClosure*) closure;
-  register gpointer data1, data2;
-
-  g_return_if_fail (n_param_values == 3);
-
-  if (G_CCLOSURE_SWAP_DATA (closure))
-    {
-      data1 = closure->data;
-      data2 = g_value_peek_pointer (param_values + 0);
-    }
-  else
-    {
-      data1 = g_value_peek_pointer (param_values + 0);
-      data2 = closure->data;
-    }
-  callback = (GMarshalFunc_VOID__STRING_BOOLEAN) (marshal_data ? marshal_data : cc->callback);
-
-  callback (data1,
-            g_marshal_value_peek_string (param_values + 1),
-            g_marshal_value_peek_boolean (param_values + 2),
-            data2);
-}
-
 G_END_DECLS
 
 #endif /* __ephy_marshal_MARSHAL_H__ */
