@@ -16,12 +16,13 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-bookmarks.c,v 1.95 2004/12/13 19:04:01 chpe Exp $
+ *  $Id: ephy-bookmarks.c,v 1.100 2005/01/20 19:04:31 jframeau Exp $
  */
 
 #include "config.h"
 
 #include "ephy-bookmarks.h"
+#include "ephy-bookmarks-type-builtins.h"
 #include "ephy-file-helpers.h"
 #include "ephy-embed-shell.h"
 #include "ephy-shell.h"
@@ -51,7 +52,7 @@
 
 #define EPHY_BOOKMARKS_GET_PRIVATE(object)(G_TYPE_INSTANCE_GET_PRIVATE ((object), EPHY_TYPE_BOOKMARKS, EphyBookmarksPrivate))
 
-struct EphyBookmarksPrivate
+struct _EphyBookmarksPrivate
 {
 	EphyBookmarksBarModel *toolbars_model;
 	gboolean init_defaults;
@@ -138,6 +139,10 @@ ephy_bookmarks_get_type (void)
                         0, /* n_preallocs */
                         (GInstanceInitFunc) ephy_bookmarks_init
                 };
+		volatile GType flags_type; /* work around gcc's optimiser */
+      
+		/* make sure the flags type is known */
+	      	flags_type = EPHY_TYPE_BOOKMARK_PROPERTY;
 
                 type = g_type_register_static (G_TYPE_OBJECT,
 					       "EphyBookmarks",
@@ -538,16 +543,16 @@ redirect_cb (EphyHistory *history,
 	gtk_message_dialog_format_secondary_markup
 		(GTK_MESSAGE_DIALOG (dialog),
 		/* translators: the %s is a URL */
-		_("The bookmarked page has moved to <tt>%s</tt>."),
+		_("The bookmarked page has moved to \"%s\"."),
 		to_uri);
 
 	gtk_dialog_add_button (GTK_DIALOG (dialog),
-				_("_Don't update bookmark"), GTK_RESPONSE_REJECT);
+				_("_Don't Update"), GTK_RESPONSE_REJECT);
 	gtk_dialog_add_button (GTK_DIALOG (dialog),
-				_("_Update bookmark"), GTK_RESPONSE_ACCEPT);
+				_("_Update"), GTK_RESPONSE_ACCEPT);
 	gtk_dialog_set_default_response (GTK_DIALOG (dialog), GTK_RESPONSE_REJECT);
 
-	gtk_window_set_title (GTK_WINDOW (dialog), _("Update bookmark?"));
+	gtk_window_set_title (GTK_WINDOW (dialog), _("Update Bookmark?"));
 	gtk_window_set_icon_name (GTK_WINDOW (dialog), "web-browser");
 
 	g_object_set_data_full (G_OBJECT (dialog), UPDATE_URI_DATA_KEY,
@@ -782,7 +787,10 @@ ephy_bookmarks_init (EphyBookmarks *eb)
 	/* Bookmarks */
 	eb->priv->bookmarks = ephy_node_new_with_id (db, BOOKMARKS_NODE_ID);
 	g_value_init (&value, G_TYPE_STRING);
-	g_value_set_string (&value, _("All"));
+	/* Translators: The text before the "|" is context to help you decide on
+	 * the correct translation. You MUST OMIT it in the translated string. */
+	/* Translators: this topic contains all bookmarks */
+	g_value_set_string (&value, Q_("bookmarks|All"));
 	ephy_node_set_property (eb->priv->bookmarks,
 			        EPHY_NODE_KEYWORD_PROP_NAME,
 			        &value);
@@ -815,7 +823,10 @@ ephy_bookmarks_init (EphyBookmarks *eb)
 	/* Favorites */
 	eb->priv->favorites = ephy_node_new_with_id (db, FAVORITES_NODE_ID);
 	g_value_init (&value, G_TYPE_STRING);
-	g_value_set_string (&value, _("Most Visited"));
+	/* Translators: The text before the "|" is context to help you decide on
+	 * the correct translation. You MUST OMIT it in the translated string. */
+	/* Translators: this topic contains the most used bookmarks */
+	g_value_set_string (&value, Q_("bookmarks|Most Visited"));
 	ephy_node_set_property (eb->priv->favorites,
 			        EPHY_NODE_KEYWORD_PROP_NAME,
 			        &value);
@@ -831,7 +842,10 @@ ephy_bookmarks_init (EphyBookmarks *eb)
 	/* Not categorized */
 	eb->priv->notcategorized = ephy_node_new_with_id (db, BMKS_NOTCATEGORIZED_NODE_ID);
 	g_value_init (&value, G_TYPE_STRING);
-	g_value_set_string (&value, _("Not Categorized"));
+	/* Translators: The text before the "|" is context to help you decide on
+	 * the correct translation. You MUST OMIT it in the translated string. */
+	/* Translators: this topic contains the not categorized bookmarks */
+	g_value_set_string (&value, Q_("bookmarks|Not Categorized"));
 	ephy_node_set_property (eb->priv->notcategorized,
 			        EPHY_NODE_KEYWORD_PROP_NAME,
 			        &value);
