@@ -16,7 +16,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-topic-action.c,v 1.66 2005/01/04 21:42:58 chpe Exp $
+ *  $Id: ephy-topic-action.c,v 1.68 2005/01/15 20:30:49 chpe Exp $
  */
 
 #include "config.h"
@@ -445,8 +445,8 @@ add_open_in_tabs_menu (EphyTopicAction *action,
 	GtkWidget *item;
 	const char *label;
 
-	label = ngettext ("_Open in New Tab",
-			  "_Open in New Tabs",
+	label = ngettext ("Open in New _Tab",
+			  "Open in New _Tabs",
 			  ephy_node_get_n_children (node));
 
 	item = gtk_menu_item_new_with_mnemonic (label);
@@ -755,7 +755,7 @@ show_context_menu (EphyTopicAction *action,
 		   GdkEventButton *event,
 		   GtkMenuPositionFunc func)
 {
-	GtkWidget *menu, *item;
+	GtkWidget *menu, *item, *image;
 	gboolean last;
 
 	menu = gtk_menu_new ();
@@ -767,8 +767,11 @@ show_context_menu (EphyTopicAction *action,
 	gtk_widget_show (item);
 	gtk_menu_shell_append (GTK_MENU_SHELL (menu), item);
 
-	item = gtk_image_menu_item_new_from_stock (GTK_STOCK_REMOVE, NULL);
+	item = gtk_image_menu_item_new_with_mnemonic (_("_Remove from Toolbar"));
 	gtk_widget_show (item);
+	image = gtk_image_new_from_stock (GTK_STOCK_REMOVE, GTK_ICON_SIZE_MENU);
+	gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM (item), image);
+	gtk_widget_show (image);
 	gtk_menu_shell_append (GTK_MENU_SHELL (menu), item);
 	g_signal_connect (item, "activate",
 			  G_CALLBACK (remove_activate_cb), proxy);
