@@ -16,7 +16,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-topics-selector.c,v 1.30 2005/01/08 19:41:47 chpe Exp $
+ *  $Id: ephy-topics-selector.c,v 1.31 2005/01/21 19:33:03 jbaayen Exp $
  */
 
 #include "config.h"
@@ -200,7 +200,7 @@ ephy_topics_selector_constructor (GType type,
 				   EPHY_NODE_KEYWORD_PROP_NAME,
 				   EPHY_NODE_VIEW_SHOW_PRIORITY |
 				   EPHY_NODE_VIEW_EDITABLE |
-				   EPHY_NODE_VIEW_SEARCHABLE, NULL);
+				   EPHY_NODE_VIEW_SEARCHABLE, NULL, NULL);
 	ephy_node_view_set_sort (EPHY_NODE_VIEW (selector), G_TYPE_STRING,
 				 EPHY_NODE_KEYWORD_PROP_NAME, GTK_SORT_ASCENDING);
 
