@@ -16,7 +16,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-history-window.c,v 1.89 2005/01/08 19:41:47 chpe Exp $
+ *  $Id: ephy-history-window.c,v 1.93 2005/01/21 19:33:02 jbaayen Exp $
  */
 
 #include "config.h"
@@ -59,7 +59,6 @@
 #include "ephy-new-bookmark.h"
 #include "ephy-stock-icons.h"
 #include "ephy-gui.h"
-#include "toolbar.h"
 #include "ephy-stock-icons.h"
 #include "ephy-search-entry.h"
 #include "ephy-session.h"
@@ -71,9 +70,9 @@
 
 static GtkTargetEntry page_drag_types [] =
 {
-        { EPHY_DND_URI_LIST_TYPE,   0, 0 },
-        { EPHY_DND_TEXT_TYPE,       0, 1 },
-        { EPHY_DND_URL_TYPE,        0, 2 }
+        { EPHY_DND_URL_TYPE,        0, 0 },
+        { EPHY_DND_URI_LIST_TYPE,   0, 1 },
+        { EPHY_DND_TEXT_TYPE,       0, 2 }
 };
 static int n_page_drag_types = G_N_ELEMENTS (page_drag_types);
 
@@ -169,7 +168,7 @@ static GtkActionEntry ephy_history_ui_entries [] = {
 	{ "PopupAction", NULL, "" },
 
 	/* File Menu */
-	{ "OpenInWindow", GTK_STOCK_OPEN, N_("_Open in New Window"), "<control>O",
+	{ "OpenInWindow", GTK_STOCK_OPEN, N_("Open in New _Window"), "<control>O",
 	  N_("Open the selected history link in a new window"),
 	  G_CALLBACK (cmd_open_bookmarks_in_browser) },
 	{ "OpenInTab", STOCK_NEW_TAB, N_("Open in New _Tab"), "<shift><control>O",
@@ -709,8 +708,8 @@ ephy_history_window_update_menu (EphyHistoryWindow *editor)
 		select_all = pages_focus;
 	}
 
-	open_in_window_label = ngettext ("_Open in New Window",
-					 "_Open in New Windows",
+	open_in_window_label = ngettext ("Open in New _Window",
+					 "Open in New _Windows",
 					 num_pages_selected);
 	open_in_tab_label = ngettext ("Open in New _Tab",
 				      "Open in New _Tabs",
@@ -1190,7 +1189,7 @@ ephy_history_window_construct (EphyHistoryWindow *editor)
 	EphyNode *node;
 	GtkUIManager *ui_merge;
 	GtkActionGroup *action_group;
-	int col_id, details_value;
+	int url_col_id, title_col_id, details_value;
 
 	gtk_window_set_title (GTK_WINDOW (editor), _("History"));
 	gtk_window_set_icon_name (GTK_WINDOW (editor), EPHY_STOCK_HISTORY);
@@ -1250,21 +1249,24 @@ ephy_history_window_construct (EphyHistoryWindow *editor)
 	editor->priv->sites_filter = ephy_node_filter_new ();
 	sites_view = ephy_node_view_new (node, editor->priv->sites_filter);
 	add_focus_monitor (editor, sites_view);
-	col_id = ephy_node_view_add_data_column (EPHY_NODE_VIEW (sites_view),
-					         G_TYPE_STRING,
-					         EPHY_NODE_PAGE_PROP_LOCATION,
-						 NULL, NULL);
+	url_col_id = ephy_node_view_add_data_column (EPHY_NODE_VIEW (sites_view),
+					             G_TYPE_STRING,
+					             EPHY_NODE_PAGE_PROP_LOCATION,
+						     NULL, NULL);
+	title_col_id = ephy_node_view_add_column (EPHY_NODE_VIEW (sites_view), _("Sites"),
+						  G_TYPE_STRING,
+						  EPHY_NODE_PAGE_PROP_TITLE,
+						  EPHY_NODE_VIEW_SEARCHABLE |
+						  EPHY_NODE_VIEW_SHOW_PRIORITY,
+						  provide_favicon,
+						  NULL);
 	ephy_node_view_enable_drag_source (EPHY_NODE_VIEW (sites_view),
 					   page_drag_types,
-				           n_page_drag_types, col_id);
+				           n_page_drag_types,
+					   url_col_id,
+					   title_col_id);
 	selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (sites_view));
 	gtk_tree_selection_set_mode (selection, GTK_SELECTION_BROWSE);
-	ephy_node_view_add_column (EPHY_NODE_VIEW (sites_view), _("Sites"),
-				   G_TYPE_STRING,
-				   EPHY_NODE_PAGE_PROP_TITLE,
-				   EPHY_NODE_VIEW_SEARCHABLE |
-				   EPHY_NODE_VIEW_SHOW_PRIORITY,
-				   provide_favicon);
 	ephy_node_view_set_priority (EPHY_NODE_VIEW (sites_view),
 				     EPHY_NODE_PAGE_PROP_PRIORITY);
 	ephy_node_view_set_sort (EPHY_NODE_VIEW (sites_view), G_TYPE_STRING,
@@ -1314,24 +1316,21 @@ ephy_history_window_construct (EphyHistoryWindow *editor)
 	add_focus_monitor (editor, pages_view);
 	selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (pages_view));
 	gtk_tree_view_set_rules_hint (GTK_TREE_VIEW (pages_view), TRUE);
-	col_id = ephy_node_view_add_data_column (EPHY_NODE_VIEW (pages_view),
-					         G_TYPE_STRING,
-					         EPHY_NODE_PAGE_PROP_LOCATION,
-						 NULL, NULL);
-	ephy_node_view_enable_drag_source (EPHY_NODE_VIEW (pages_view),
-					   page_drag_types,
-				           n_page_drag_types, col_id);
-	col = ephy_node_view_add_column (EPHY_NODE_VIEW (pages_view), _("Title"),
-				         G_TYPE_STRING, EPHY_NODE_PAGE_PROP_TITLE,
-				         EPHY_NODE_VIEW_SORTABLE |
-					 EPHY_NODE_VIEW_SEARCHABLE, NULL);
+	title_col_id = ephy_node_view_add_column (EPHY_NODE_VIEW (pages_view), _("Title"),
+				                  G_TYPE_STRING, EPHY_NODE_PAGE_PROP_TITLE,
+				                  EPHY_NODE_VIEW_SORTABLE |
+					          EPHY_NODE_VIEW_SEARCHABLE, NULL, &col);
 	gtk_tree_view_column_set_max_width (col, 250);
 	editor->priv->title_col = col;
-	col = ephy_node_view_add_column (EPHY_NODE_VIEW (pages_view), _("Address"),
-				         G_TYPE_STRING, EPHY_NODE_PAGE_PROP_LOCATION,
-				         EPHY_NODE_VIEW_SORTABLE, NULL);
+	url_col_id = ephy_node_view_add_column (EPHY_NODE_VIEW (pages_view), _("Address"),
+				                G_TYPE_STRING, EPHY_NODE_PAGE_PROP_LOCATION,
+				                EPHY_NODE_VIEW_SORTABLE, NULL, &col);
 	gtk_tree_view_column_set_max_width (col, 200);
 	editor->priv->address_col = col;
+	ephy_node_view_enable_drag_source (EPHY_NODE_VIEW (pages_view),
+					   page_drag_types,
+				           n_page_drag_types,
+					   url_col_id, title_col_id);
 	ephy_node_view_set_sort (EPHY_NODE_VIEW (pages_view), G_TYPE_INT,
 				 EPHY_NODE_PAGE_PROP_LAST_VISIT,
 				 GTK_SORT_DESCENDING);
