@@ -1,6 +1,6 @@
 /*
- *  Copyright (C) 2003 Marco Pesenti Gritti
- *  Copyright (C) 2003 Christian Persch
+ *  Copyright (C) 2003, 2004 Marco Pesenti Gritti
+ *  Copyright (C) 2003, 2004 Christian Persch
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -16,31 +16,39 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-location-action.c,v 1.24 2004/04/09 21:08:02 chpe Exp $
+ *  $Id: ephy-location-action.c,v 1.33 2005/01/13 23:47:32 chpe Exp $
  */
 
-#ifdef HAVE_CONFIG_H
 #include "config.h"
-#endif
 
 #include "ephy-location-action.h"
 #include "ephy-location-entry.h"
 #include "ephy-shell.h"
+#include "ephy-favicon-cache.h"
 #include "ephy-completion-model.h"
+#include "ephy-link.h"
 #include "ephy-debug.h"
 
 #include <gtk/gtkentry.h>
+#include <gtk/gtkstock.h>
+#include <gtk/gtkimage.h>
 #include <gtk/gtkentrycompletion.h>
 
 #define EPHY_LOCATION_ACTION_GET_PRIVATE(object)(G_TYPE_INSTANCE_GET_PRIVATE ((object), EPHY_TYPE_LOCATION_ACTION, EphyLocationActionPrivate))
 
 struct _EphyLocationActionPrivate
 {
+	EphyWindow *window;
 	GList *actions;
 	char *address;
 	gboolean editable;
 	EphyNode *smart_bmks;
 	EphyBookmarks *bookmarks;
+	char *icon;
+	EphyFaviconCache *cache;
+	char *lock_stock_id;
+	char *lock_tooltip;
+	gboolean show_lock;
 };
 
 static void ephy_location_action_init       (EphyLocationAction *action);
@@ -56,25 +64,22 @@ enum
 {
 	PROP_0,
 	PROP_ADDRESS,
-	PROP_EDITABLE
-};
-
-enum
-{
-	GO_LOCATION,
-	LAST_SIGNAL
+	PROP_EDITABLE,
+	PROP_ICON,
+	PROP_LOCK_STOCK,
+	PROP_LOCK_TOOLTIP,
+	PROP_SHOW_LOCK,
+	PROP_WINDOW
 };
 
 static GObjectClass *parent_class = NULL;
 
-static guint signals[LAST_SIGNAL] = { 0 };
-
 GType
 ephy_location_action_get_type (void)
 {
 	static GType type = 0;
 
-	if (!type)
+	if (G_UNLIKELY (type == 0))
 	{
 		static const GTypeInfo type_info =
 		{
@@ -89,10 +94,11 @@ ephy_location_action_get_type (void)
 			(GInstanceInitFunc) ephy_location_action_init,
 		};
 
-		type = g_type_register_static (GTK_TYPE_ACTION,
+		type = g_type_register_static (EPHY_TYPE_LINK_ACTION,
 					       "EphyLocationAction",
 					       &type_info, 0);
 	}
+
 	return type;
 }
 
@@ -121,8 +127,8 @@ action_activated_cb (GtkEntryCompletion *completion,
 			(action->priv->bookmarks, smart_url, content);
 		g_return_if_fail (url != NULL);
 
-		g_signal_emit (action, signals[GO_LOCATION], 0, url);
-
+		ephy_link_open (EPHY_LINK (action), url, NULL, 0);
+	
 		g_free (url);
 		g_free (content);
 	}
@@ -135,9 +141,9 @@ location_url_activate_cb (GtkEntry *entry,
 	const char *content;
 
 	content = gtk_entry_get_text (entry);
-	if (content)
+	if (content != NULL)
 	{
-		g_signal_emit (action, signals[GO_LOCATION], 0, content);
+		ephy_link_open (EPHY_LINK (action), content, NULL, 0);
 	}
 }
 
@@ -156,93 +162,168 @@ user_changed_cb (GtkWidget *proxy, EphyLocationAction *action)
 }
 
 static void
-sync_address (GtkAction *act, GParamSpec *pspec, GtkWidget *proxy)
+sync_address (GtkAction *gaction,
+	      GParamSpec *pspec,
+	      GtkWidget *proxy)
 {
-	EphyLocationAction *action = EPHY_LOCATION_ACTION (act);
+	EphyLocationAction *action = EPHY_LOCATION_ACTION (gaction);
+	EphyLocationEntry *lentry = EPHY_LOCATION_ENTRY (proxy);
 
-	LOG ("sync_address")
+	LOG ("sync_address %s", action->priv->address)
 
-	g_return_if_fail (EPHY_IS_LOCATION_ENTRY (proxy));
 	g_signal_handlers_block_by_func (proxy, G_CALLBACK (user_changed_cb), action);
-	ephy_location_entry_set_location (EPHY_LOCATION_ENTRY (proxy),
-					  action->priv->address);
+	ephy_location_entry_set_location (lentry, action->priv->address);
 	g_signal_handlers_unblock_by_func (proxy, G_CALLBACK (user_changed_cb), action);
 }
 
 static void
-sync_editable (GtkAction *act, GParamSpec *pspec, GtkWidget *proxy)
+sync_editable (GtkAction *gaction,
+	       GParamSpec *pspec,
+	       GtkWidget *proxy)
 {
-	EphyLocationAction *action = EPHY_LOCATION_ACTION (act);
+	EphyLocationAction *action = EPHY_LOCATION_ACTION (gaction);
+	EphyLocationEntry *lentry = EPHY_LOCATION_ENTRY (proxy);
 	GtkWidget *entry;
 
-	entry = GTK_BIN (proxy)->child;
+	entry = ephy_location_entry_get_entry (lentry);
 	gtk_editable_set_editable (GTK_EDITABLE (entry), action->priv->editable);
 }
 
 static void
-remove_completion_actions (GtkAction *action, GtkWidget *proxy)
+sync_icon (GtkAction *gaction,
+	   GParamSpec *pspec,
+	   GtkWidget *proxy)
 {
+	EphyLocationAction *action = EPHY_LOCATION_ACTION (gaction);
+	EphyLocationActionPrivate *priv = action->priv;
+	EphyLocationEntry *entry = EPHY_LOCATION_ENTRY (proxy);
+	GdkPixbuf *pixbuf;
+
+	pixbuf = ephy_favicon_cache_get (priv->cache, priv->icon);
+
+	ephy_location_entry_set_favicon (entry, pixbuf);
+
+	if (pixbuf != NULL)
+	{
+		g_object_unref (pixbuf);
+	}
+}
+
+static void
+sync_lock_stock_id (GtkAction *gaction,
+		    GParamSpec *pspec,
+		    GtkWidget *proxy)
+{
+	EphyLocationAction *action = EPHY_LOCATION_ACTION (gaction);
+	EphyLocationActionPrivate *priv = action->priv;
+	EphyLocationEntry *entry = EPHY_LOCATION_ENTRY (proxy);
+
+	ephy_location_entry_set_lock_stock (entry, priv->lock_stock_id);
+}
+
+static void
+sync_lock_tooltip (GtkAction *gaction,
+		   GParamSpec *pspec,
+		   GtkWidget *proxy)
+{
+	EphyLocationAction *action = EPHY_LOCATION_ACTION (gaction);
+	EphyLocationActionPrivate *priv = action->priv;
+	EphyLocationEntry *entry = EPHY_LOCATION_ENTRY (proxy);
+
+	ephy_location_entry_set_lock_tooltip (entry, priv->lock_tooltip);
+}
+
+static void
+sync_show_lock (GtkAction *gaction,
+	        GParamSpec *pspec,
+	        GtkWidget *proxy)
+{
+	EphyLocationAction *action = EPHY_LOCATION_ACTION (gaction);
+	EphyLocationActionPrivate *priv = action->priv;
+	EphyLocationEntry *entry = EPHY_LOCATION_ENTRY (proxy);
+
+	ephy_location_entry_set_show_lock (entry, priv->show_lock);
+}
+
+static char *
+get_location_cb (EphyLocationEntry *entry,
+		EphyLocationAction *action)
+{
+	EphyEmbed *embed;
+	
+	embed = ephy_window_get_active_embed (action->priv->window);
+	
+	return ephy_embed_get_location (embed, TRUE);
+}
+
+static char *
+get_title_cb (EphyLocationEntry *entry,
+	      EphyLocationAction *action)
+{
+	EphyTab *tab;
+
+	tab = ephy_window_get_active_tab (action->priv->window);
+
+	return g_strdup (ephy_tab_get_title (tab));
+}
+
+static void
+remove_completion_actions (GtkAction *gaction,
+			   GtkWidget *proxy)
+{
+	EphyLocationAction *action = EPHY_LOCATION_ACTION (gaction);
+	EphyLocationEntry *lentry = EPHY_LOCATION_ENTRY (proxy);
 	GtkWidget *entry;
 	GtkEntryCompletion *completion;
-	EphyLocationAction *la = EPHY_LOCATION_ACTION (action);
 	GList *l;
 
-	entry = GTK_BIN (proxy)->child;
+	entry = ephy_location_entry_get_entry (lentry);
 	completion = gtk_entry_get_completion (GTK_ENTRY (entry));
 
-	for (l = la->priv->actions; l != NULL; l = l->next)
+	for (l = action->priv->actions; l != NULL; l = l->next)
 	{
 		gtk_entry_completion_delete_action (completion, 0);
 	}
 
 	g_signal_handlers_disconnect_by_func
-			(completion, G_CALLBACK (action_activated_cb), la);
+			(completion, G_CALLBACK (action_activated_cb), action);
 }
 
 static void
-add_completion_actions (GtkAction *action, GtkWidget *proxy)
+add_completion_actions (GtkAction *gaction,
+			GtkWidget *proxy)
 {
+	EphyLocationAction *action = EPHY_LOCATION_ACTION (gaction);
+	EphyLocationEntry *lentry = EPHY_LOCATION_ENTRY (proxy);
 	GtkWidget *entry;
 	GtkEntryCompletion *completion;
-	EphyLocationAction *la = EPHY_LOCATION_ACTION (action);
 	GList *l;
 
-	entry = GTK_BIN (proxy)->child;
+	entry = ephy_location_entry_get_entry (lentry);
 	completion = gtk_entry_get_completion (GTK_ENTRY (entry));
 
-	for (l = la->priv->actions; l != NULL; l = l->next)
+	for (l = action->priv->actions; l != NULL; l = l->next)
 	{
 		EphyNode *bmk = l->data;
 		const char *title;
 		int index;
 
-		index = g_list_position (la->priv->actions, l);
+		index = g_list_position (action->priv->actions, l);
 		title = ephy_node_get_property_string
 	                (bmk, EPHY_NODE_BMK_PROP_TITLE);
 		gtk_entry_completion_insert_action_text (completion, index, (char*)title);
 	}
 
 	g_signal_connect (completion, "action_activated",
-			  G_CALLBACK (action_activated_cb), la);
-}
-
-static gboolean
-create_menu_proxy_cb (GtkToolItem *tool_item, 
-		      GtkAction *action)
-{
-	gtk_tool_item_set_proxy_menu_item
-		(tool_item, "ephy-location-action-menu-item", NULL);
-
-	return TRUE;
+			  G_CALLBACK (action_activated_cb), action);
 }
 
 static void
 connect_proxy (GtkAction *action, GtkWidget *proxy)
 {
-	LOG ("Connect proxy")
-
 	if (EPHY_IS_LOCATION_ENTRY (proxy))
 	{
+		EphyLocationEntry *lentry = EPHY_LOCATION_ENTRY (proxy);
 		EphyCompletionModel *model;
 		GtkWidget *entry;
 
@@ -262,49 +343,53 @@ connect_proxy (GtkAction *action, GtkWidget *proxy)
 		sync_editable (action, NULL, proxy);
 		g_signal_connect_object (action, "notify::editable",
 					 G_CALLBACK (sync_editable), proxy, 0);
+		sync_icon (action, NULL, proxy);
+		g_signal_connect_object (action, "notify::icon",
+					 G_CALLBACK (sync_icon), proxy, 0);
+		sync_lock_stock_id (action, NULL, proxy);
+		g_signal_connect_object (action, "notify::lock-stock-id",
+					 G_CALLBACK (sync_lock_stock_id), proxy, 0);
+		sync_lock_tooltip (action, NULL, proxy);
+		g_signal_connect_object (action, "notify::lock-tooltip",
+					 G_CALLBACK (sync_lock_tooltip), proxy, 0);
+		sync_show_lock (action, NULL, proxy);
+		g_signal_connect_object (action, "notify::show-lock",
+					 G_CALLBACK (sync_show_lock), proxy, 0);
 
-		entry = GTK_BIN (proxy)->child;
+		entry = ephy_location_entry_get_entry (lentry);
 		g_signal_connect_object (entry, "activate",
 					 G_CALLBACK (location_url_activate_cb),
 					 action, 0);
 		g_signal_connect_object (proxy, "user_changed",
 					 G_CALLBACK (user_changed_cb), action, 0);
+		g_signal_connect_object (proxy, "get-location",
+					 G_CALLBACK (get_location_cb), action, 0);
+		g_signal_connect_object (proxy, "get-title",
+					 G_CALLBACK (get_title_cb), action, 0);
 	}
 
-	/* we need to connect to this before chaining up, since gtkaction's
-	 * connect_proxy connects a routine there which uses create_menu_item
-	 * method to generate a menu proxy (and create_menu_item CANNOT return
-	 * NULL. See bug #133446.)
-	 */
-	g_signal_connect_object (proxy, "create_menu_proxy",
-				 G_CALLBACK (create_menu_proxy_cb),
-				 action, 0);
-
-	(* GTK_ACTION_CLASS (parent_class)->connect_proxy) (action, proxy);
+	GTK_ACTION_CLASS (parent_class)->connect_proxy (action, proxy);
 }
 
 static void
 disconnect_proxy (GtkAction *action, GtkWidget *proxy)
 {
-	LOG ("Disconnect proxy")
+	GTK_ACTION_CLASS (parent_class)->disconnect_proxy (action, proxy);
 
 	if (EPHY_IS_LOCATION_ENTRY (proxy))
 	{
+		EphyLocationEntry *lentry = EPHY_LOCATION_ENTRY (proxy);
 		GtkWidget *entry;
 
-		entry = GTK_BIN (proxy)->child;
+		entry = ephy_location_entry_get_entry (lentry);
 
-		g_signal_handlers_disconnect_by_func
-			(action, G_CALLBACK (sync_address), proxy);
-
-		g_signal_handlers_disconnect_by_func
-			(entry, G_CALLBACK (location_url_activate_cb), action);
-
-		g_signal_handlers_disconnect_by_func
-			(proxy, G_CALLBACK (user_changed_cb), action);
+		g_signal_handlers_disconnect_matched (action, G_SIGNAL_MATCH_DATA,
+						      0, 0, NULL, NULL, proxy);
+		g_signal_handlers_disconnect_matched (proxy, G_SIGNAL_MATCH_DATA,
+						      0, 0, NULL, NULL, action);
+		g_signal_handlers_disconnect_matched (entry, G_SIGNAL_MATCH_DATA,
+						      0, 0, NULL, NULL, action);
 	}
-
-	(* GTK_ACTION_CLASS (parent_class)->disconnect_proxy) (action, proxy);
 }
 
 static void
@@ -323,6 +408,24 @@ ephy_location_action_set_property (GObject *object,
 		case PROP_EDITABLE:
 			action->priv->editable = g_value_get_boolean (value);
 			break;
+		case PROP_ICON:
+			g_free (action->priv->icon);
+			action->priv->icon = g_value_dup_string (value);
+			break;
+		case PROP_LOCK_STOCK:
+			g_free (action->priv->lock_stock_id);
+			action->priv->lock_stock_id = g_value_dup_string (value);
+			break;
+		case PROP_LOCK_TOOLTIP:
+			g_free (action->priv->lock_tooltip);
+			action->priv->lock_tooltip = g_value_dup_string (value);
+			break;
+		case PROP_SHOW_LOCK:
+			action->priv->show_lock = g_value_get_boolean (value);
+			break;
+		case PROP_WINDOW:
+			action->priv->window = EPHY_WINDOW (g_value_get_object (value));
+			break;
 	}
 }
 
@@ -342,20 +445,21 @@ ephy_location_action_get_property (GObject *object,
 		case PROP_EDITABLE:
 			g_value_set_boolean (value, action->priv->editable);
 			break;
-	}
-}
-
-static void
-ephy_location_action_activate (GtkAction *action)
-{
-	GSList *proxies;
-
-	/* Note: this makes sense only for a single proxy */
-	proxies = gtk_action_get_proxies (action);
-
-	if (proxies && EPHY_IS_LOCATION_ENTRY (proxies->data))
-	{
-		ephy_location_entry_activate (EPHY_LOCATION_ENTRY (proxies->data));
+		case PROP_ICON:
+			g_value_set_string (value, action->priv->icon);
+			break;
+		case PROP_LOCK_STOCK:
+			g_value_set_string (value, action->priv->lock_stock_id);
+			break;
+		case PROP_LOCK_TOOLTIP:
+			g_value_set_string (value, action->priv->lock_tooltip);
+			break;
+		case PROP_SHOW_LOCK:
+			g_value_set_boolean (value, action->priv->show_lock);
+			break;
+		case PROP_WINDOW:
+			/* not readable */
+			break;
 	}
 }
 
@@ -374,18 +478,6 @@ ephy_location_action_class_init (EphyLocationActionClass *class)
 	action_class->toolbar_item_type = EPHY_TYPE_LOCATION_ENTRY;
 	action_class->connect_proxy = connect_proxy;
 	action_class->disconnect_proxy = disconnect_proxy;
-	action_class->activate = ephy_location_action_activate;
-
-	signals[GO_LOCATION] =
-                g_signal_new ("go_location",
-                              G_OBJECT_CLASS_TYPE (object_class),
-                              G_SIGNAL_RUN_FIRST,
-                              G_STRUCT_OFFSET (EphyLocationActionClass, go_location),
-                              NULL, NULL,
-                              g_cclosure_marshal_VOID__STRING,
-                              G_TYPE_NONE,
-                              1,
-			      G_TYPE_STRING);
 
 	g_object_class_install_property (object_class,
 					 PROP_ADDRESS,
@@ -402,6 +494,46 @@ ephy_location_action_class_init (EphyLocationActionClass *class)
 							       TRUE,
 							       G_PARAM_READWRITE));
 
+	g_object_class_install_property (object_class,
+					 PROP_ICON,
+					 g_param_spec_string  ("icon",
+							       "Icon",
+							       "The icon",
+							       NULL,
+							       G_PARAM_READWRITE));
+
+	g_object_class_install_property (object_class,
+					 PROP_LOCK_STOCK,
+					 g_param_spec_string  ("lock-stock-id",
+							       "Lock Stock ID",
+							       "Lock Stock ID",
+							       NULL,
+							       G_PARAM_READWRITE));
+
+	g_object_class_install_property (object_class,
+					 PROP_LOCK_TOOLTIP,
+					 g_param_spec_string  ("lock-tooltip",
+							       "Lock Tooltip",
+							       "The icon",
+							       NULL,
+							       G_PARAM_READWRITE));
+
+	g_object_class_install_property (object_class,
+					 PROP_SHOW_LOCK,
+					 g_param_spec_boolean ("show-lock",
+							       "Show Lock",
+							       "Show Lock",
+							       FALSE,
+							       G_PARAM_READWRITE));
+
+	g_object_class_install_property (object_class,
+					 PROP_WINDOW,
+					 g_param_spec_object ("window",
+							      "Window",
+							      "The navigation window",
+							      G_TYPE_OBJECT,
+							      G_PARAM_WRITABLE |
+							      G_PARAM_CONSTRUCT_ONLY));
 
 	g_type_class_add_private (object_class, sizeof (EphyLocationActionPrivate));
 }
@@ -516,7 +648,6 @@ ephy_location_action_init (EphyLocationAction *action)
 	action->priv = EPHY_LOCATION_ACTION_GET_PRIVATE (action);
 
 	action->priv->address = g_strdup ("");
-	action->priv->actions = NULL;
 	action->priv->editable = TRUE;
 	action->priv->bookmarks = ephy_shell_get_bookmarks (ephy_shell);
 	action->priv->smart_bmks = ephy_bookmarks_get_smart_bookmarks
@@ -536,16 +667,24 @@ ephy_location_action_init (EphyLocationAction *action)
 			                 EPHY_NODE_CHILD_CHANGED,
 			                 (EphyNodeCallback)actions_child_changed_cb,
 			                 G_OBJECT (action));
+
+	action->priv->cache = EPHY_FAVICON_CACHE
+		(ephy_embed_shell_get_favicon_cache (embed_shell));
+	g_object_ref (action->priv->cache);
 }
 
 static void
 ephy_location_action_finalize (GObject *object)
 {
 	EphyLocationAction *action = EPHY_LOCATION_ACTION (object);
+	EphyLocationActionPrivate *priv = action->priv;
 
-	g_list_free (action->priv->actions);
-
-	g_free (action->priv->address);
+	g_list_free (priv->actions);
+	g_free (priv->address);
+	g_free (priv->icon);
+	g_free (priv->lock_stock_id);
+	g_free (priv->lock_tooltip);
+	g_object_unref (priv->cache);
 
 	G_OBJECT_CLASS (parent_class)->finalize (object);
 }
