@@ -17,7 +17,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-notebook.c,v 1.59 2004/11/27 23:41:02 chpe Exp $
+ *  $Id: ephy-notebook.c,v 1.67 2005/01/10 00:23:14 chpe Exp $
  */
 
 #include "config.h"
@@ -32,10 +32,10 @@
 #include "ephy-embed.h"
 #include "ephy-window.h"
 #include "ephy-shell.h"
-#include "ephy-debug.h"
 #include "ephy-favicon-cache.h"
 #include "ephy-spinner.h"
-#include "ephy-string.h"
+#include "ephy-link.h"
+#include "ephy-debug.h"
 
 #include <glib-object.h>
 #include <gtk/gtkeventbox.h>
@@ -52,14 +52,16 @@
 #include <glib/gi18n.h>
 #include <libgnomevfs/gnome-vfs-uri.h>
 
-#define TAB_WIDTH_N_CHARS 20
+#define TAB_WIDTH_N_CHARS 15
 
 #define AFTER_ALL_TABS -1
 #define NOT_IN_APP_WINDOWS -2
 
+#define INSANE_NUMBER_OF_URLS 20
+
 #define EPHY_NOTEBOOK_GET_PRIVATE(object)(G_TYPE_INSTANCE_GET_PRIVATE ((object), EPHY_TYPE_NOTEBOOK, EphyNotebookPrivate))
 
-struct EphyNotebookPrivate
+struct _EphyNotebookPrivate
 {
 	GList *focused_pages;
 	GtkTooltips *title_tips;
@@ -104,11 +106,11 @@ static GObjectClass *parent_class = NULL;
 GType
 ephy_notebook_get_type (void)
 {
-        static GType type = 0;
+	static GType type = 0;
 
-        if (G_UNLIKELY (type == 0))
-        {
-                static const GTypeInfo our_info =
+	if (G_UNLIKELY (type == 0))
+	{
+		static const GTypeInfo our_info =
 			{
 				sizeof (EphyNotebookClass),
 				NULL, /* base_init */
@@ -121,12 +123,22 @@ ephy_notebook_get_type (void)
 				(GInstanceInitFunc) ephy_notebook_init
 			};
 
-                type = g_type_register_static (GTK_TYPE_NOTEBOOK,
-					       "EphyNotebook",
-					       &our_info, 0);
-        }
+		static const GInterfaceInfo link_info =
+		{
+			NULL,
+			NULL,
+			NULL
+		};
 
-        return type;
+	type = g_type_register_static (GTK_TYPE_NOTEBOOK,
+				       "EphyNotebook",
+				       &our_info, 0);
+	g_type_add_interface_static (type,
+				     EPHY_TYPE_LINK,
+				     &link_info);
+	}
+
+	return type;
 }
 
 static void
@@ -537,6 +549,21 @@ button_press_cb (EphyNotebook *notebook,
 					  "motion-notify-event",
 					  G_CALLBACK (motion_notify_cb), NULL);
 	}
+	else if (GDK_BUTTON_PRESS == event->type && 3 == event->button)
+	{
+		if (tab_clicked == -1)
+		{
+			/* consume event, so that we don't pop up the context menu when
+			 * the mouse if not over a tab label
+			 */
+			return TRUE;
+		}
+		else
+		{
+			/* switch to the page the mouse is over, but don't consume the event */
+			gtk_notebook_set_current_page (GTK_NOTEBOOK (notebook), tab_clicked);
+		}
+	}
 
 	return FALSE;
 }
@@ -576,6 +603,7 @@ notebook_drag_data_received_cb (GtkWidget* widget, GdkDragContext *context,
 				guint info, guint time, EphyTab *tab)
 {
 	EphyWindow *window;
+	GtkWidget *notebook;
 
 	g_signal_stop_emission_by_name (widget, "drag_data_received");
 
@@ -584,33 +612,36 @@ notebook_drag_data_received_cb (GtkWidget* widget, GdkDragContext *context,
 	if (selection_data->length <= 0 || selection_data->data == NULL) return;
 
 	window = EPHY_WINDOW (gtk_widget_get_toplevel (widget));
+	notebook = ephy_window_get_notebook (window);
 
 	if (selection_data->target == gdk_atom_intern (EPHY_DND_URL_TYPE, FALSE))
 	{
-		char *uris[2] = { NULL, NULL };
 		char **split;
 
 		/* URL_TYPE has format: url \n title */
 		split = g_strsplit (selection_data->data, "\n", 2);
-		if (split != NULL && split[0] != NULL)
+		if (split != NULL && split[0] != NULL && split[0][0] != '\0')
 		{
-			uris[0] = split[0];
-			ephy_window_load_in_tabs (window, tab, uris);
+			ephy_link_open (EPHY_LINK (notebook), split[0], tab,
+					tab ? 0 : EPHY_LINK_NEW_TAB);
 		}
 		g_strfreev (split);
 	}
 	else if (selection_data->target == gdk_atom_intern (EPHY_DND_URI_LIST_TYPE, FALSE))
 	{
 		char **uris;
+		int i;
 
 		uris = gtk_selection_data_get_uris (selection_data);
+		if (uris == NULL) return;
 
-		if (uris != NULL)
+		for (i = 0; uris[i] != NULL && i < INSANE_NUMBER_OF_URLS; i++)
 		{
-			ephy_window_load_in_tabs (window, tab, uris);
-
-			g_strfreev (uris);
+			tab = ephy_link_open (EPHY_LINK (notebook), uris[i],
+					      tab, i == 0 ? 0 : EPHY_LINK_NEW_TAB);
 		}
+
+		g_strfreev (uris);
 	}
 	else
 	{
@@ -807,12 +838,9 @@ tab_label_style_set_cb (GtkWidget *label,
 			                     label->style->font_desc,
 					     pango_context_get_language (context));
 
-	char_width = pango_font_metrics_get_approximate_char_width (metrics);
+	char_width = pango_font_metrics_get_approximate_digit_width (metrics);
 	pango_font_metrics_unref (metrics);
 
-	LOG ("tab_label_size_request_cb label %p char_width %d total %d",
-	     label, char_width, TAB_WIDTH_N_CHARS * PANGO_PIXELS (char_width))
-
 	gtk_icon_size_lookup_for_settings (gtk_widget_get_settings (label),
 					   GTK_ICON_SIZE_MENU, &w, &h);
 
@@ -842,6 +870,9 @@ build_tab_label (EphyNotebook *nb, EphyTab *tab)
 	close_button = gtk_button_new ();
 	gtk_button_set_relief (GTK_BUTTON (close_button),
 			       GTK_RELIEF_NONE);
+	/* don't allow focus on the close button */
+	gtk_button_set_focus_on_click (GTK_BUTTON (close_button), FALSE);
+
 	close_icon_size = gtk_icon_size_from_name (EPHY_ICON_SIZE_TAB_BUTTON);
 	image = gtk_image_new_from_stock (EPHY_STOCK_CLOSE_TAB, close_icon_size);
 	gtk_container_add (GTK_CONTAINER (close_button), image);
