@@ -18,7 +18,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-tab.c,v 1.133 2005/01/09 01:52:18 adamh Exp $
+ *  $Id: ephy-tab.c,v 1.135 2005/01/23 15:38:02 chpe Exp $
  */
 
 #include "config.h"
@@ -459,7 +459,7 @@ ephy_tab_class_init (EphyTabClass *class)
 
 	g_object_class_install_property (object_class,
 					 PROP_VISIBLE,
-					 g_param_spec_boolean ("visible",
+					 g_param_spec_boolean ("visibility",
 							       "Visibility",
 							       "The tab's visibility",
 							       TRUE,
@@ -1389,7 +1389,7 @@ ephy_tab_visibility_cb (EphyEmbed *embed, gboolean visibility,
 
 	tab->priv->visibility = visibility;
 
-	g_object_notify (G_OBJECT (tab), "visible");
+	g_object_notify (G_OBJECT (tab), "visibility");
 }
 
 static void
@@ -1521,9 +1521,8 @@ ephy_tab_dom_mouse_click_cb (EphyEmbed *embed,
 			     EphyEmbedEvent *event,
 			     EphyTab *tab)
 {
-	EphyEmbedEventType type;
 	EphyEmbedEventContext context;
-	guint modifier;
+	guint button, modifier;
 	gboolean handled = TRUE;
 	gboolean with_control, with_shift, is_left_click, is_middle_click;
 	gboolean is_link, is_image, is_middle_clickable;
@@ -1532,17 +1531,17 @@ ephy_tab_dom_mouse_click_cb (EphyEmbed *embed,
 
 	g_return_val_if_fail (EPHY_IS_EMBED_EVENT(event), FALSE);
 
-	type = ephy_embed_event_get_event_type (event);
+	button = ephy_embed_event_get_button (event);
 	context = ephy_embed_event_get_context (event);
 	modifier = ephy_embed_event_get_modifier (event);
 
-	LOG ("ephy_tab_dom_mouse_click_cb: type %d, context %x, modifier %x",
-	     type, context, modifier)
+	LOG ("ephy_tab_dom_mouse_click_cb: button %d, context %x, modifier %x",
+	     button, context, modifier)
 
 	with_control = (modifier & GDK_CONTROL_MASK) != 0;
 	with_shift = (modifier & GDK_SHIFT_MASK) != 0;
-	is_left_click = (type == EPHY_EMBED_EVENT_MOUSE_BUTTON1);
-	is_middle_click = (type == EPHY_EMBED_EVENT_MOUSE_BUTTON2);
+	is_left_click = (button == 1);
+	is_middle_click = (button == 2);
 
 	middle_click_opens =
 		eel_gconf_get_boolean (CONF_INTERFACE_MIDDLE_CLICK_OPEN_URL) &&
