@@ -16,7 +16,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-tab.h,v 1.19 2004/12/18 19:40:08 chpe Exp $
+ *  $Id: ephy-tab.h,v 1.23 2005/01/06 18:14:42 chpe Exp $
  */
 
 #ifndef EPHY_TAB_H
@@ -41,17 +41,17 @@ typedef struct _EphyTabPrivate	EphyTabPrivate;
 
 typedef enum
 {
-	TAB_NAV_UP	= 1 << 0,
-	TAB_NAV_BACK	= 1 << 1,
-	TAB_NAV_FORWARD	= 1 << 2
-} TabNavigationFlags;
+	EPHY_TAB_NAV_UP	= 1 << 0,
+	EPHY_TAB_NAV_BACK	= 1 << 1,
+	EPHY_TAB_NAV_FORWARD	= 1 << 2
+} EphyTabNavigationFlags;
 
 typedef enum
 {
-	TAB_ADDRESS_EXPIRE_NOW,
-	TAB_ADDRESS_EXPIRE_NEXT,
-	TAB_ADDRESS_EXPIRE_CURRENT
-} TabAddressExpire;
+	EPHY_TAB_ADDRESS_EXPIRE_NOW,
+	EPHY_TAB_ADDRESS_EXPIRE_NEXT,
+	EPHY_TAB_ADDRESS_EXPIRE_CURRENT
+} EphyTabAddressExpire;
 
 struct _EphyTab
 {
@@ -66,6 +66,10 @@ struct _EphyTabClass
 	GtkBinClass parent_class;
 };
 
+GType			ephy_tab_address_expire_get_type	(void);
+
+GType			ephy_tab_navigation_flags_get_type	(void);
+
 GType			ephy_tab_get_type		(void);
 
 EphyTab	               *ephy_tab_new			(void);
@@ -76,7 +80,7 @@ EphyEmbed              *ephy_tab_get_embed		(EphyTab *tab);
 
 EphyTab		       *ephy_tab_for_embed		(EphyEmbed *embed);
 
-EmbedDocumentType	ephy_tab_get_document_type	(EphyTab *tab);
+EphyEmbedDocumentType	ephy_tab_get_document_type	(EphyTab *tab);
 
 const char             *ephy_tab_get_icon_address	(EphyTab *tab);
 
@@ -89,13 +93,13 @@ int			ephy_tab_get_load_percent	(EphyTab *tab);
 
 void			ephy_tab_set_location		(EphyTab *tab,
 							 const char *location,
-							 TabAddressExpire expire);
+							 EphyTabAddressExpire expire);
 
 const char             *ephy_tab_get_location		(EphyTab *tab);
 
-TabNavigationFlags	ephy_tab_get_navigation_flags	(EphyTab *tab);
+EphyTabNavigationFlags	ephy_tab_get_navigation_flags	(EphyTab *tab);
 
-EmbedSecurityLevel	ephy_tab_get_security_level	(EphyTab *tab);
+EphyEmbedSecurityLevel	ephy_tab_get_security_level	(EphyTab *tab);
 
 void			ephy_tab_get_size		(EphyTab *tab,
 							 int *width,
