@@ -16,13 +16,13 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-tabs-menu.c,v 1.30 2004/11/02 20:57:21 chpe Exp $
+ *  $Id: ephy-tabs-menu.c,v 1.32 2005/01/08 16:32:09 chpe Exp $
  */
 
 #include "config.h"
 
 #include "ephy-tabs-menu.h"
-#include "ephy-string.h"
+#include "ephy-notebook.h"
 #include "ephy-marshal.h"
 #include "ephy-shell.h"
 #include "ephy-debug.h"
@@ -37,7 +37,7 @@
 #include <stdlib.h>
 #include <libxml/entities.h>
 
-#define MAX_LABEL_LENGTH 30
+#define LABEL_WIDTH_CHARS 32
 
 #define EPHY_TABS_MENU_GET_PRIVATE(object)(G_TYPE_INSTANCE_GET_PRIVATE ((object), EPHY_TYPE_TABS_MENU, EphyTabsMenuPrivate))
 
@@ -131,8 +131,13 @@ connect_proxy_cb (GtkActionGroup *action_group,
 {
 	if (GTK_IS_MENU_ITEM (proxy))
 	{
-		gtk_label_set_ellipsize (GTK_LABEL (GTK_BIN (proxy)->child),
-					 PANGO_ELLIPSIZE_END);
+		GtkLabel *label;
+
+		label = GTK_LABEL (GTK_BIN (proxy)->child);
+
+		gtk_label_set_use_underline (label, FALSE);
+		gtk_label_set_ellipsize (label, PANGO_ELLIPSIZE_END);
+		gtk_label_set_max_width_chars (label, LABEL_WIDTH_CHARS);
 	}
 }
 
