@@ -16,7 +16,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-toolbars-model.c,v 1.33 2004/11/02 20:57:21 chpe Exp $
+ *  $Id: ephy-toolbars-model.c,v 1.34 2005/01/08 16:40:45 chpe Exp $
  */
 
 #include "config.h"
@@ -32,7 +32,7 @@
 
 #define EPHY_TOOLBARS_MODEL_GET_PRIVATE(object)(G_TYPE_INSTANCE_GET_PRIVATE ((object), EPHY_TYPE_TOOLBARS_MODEL, EphyToolbarsModelPrivate))
 
-struct EphyToolbarsModelPrivate
+struct _EphyToolbarsModelPrivate
 {
 	char *xml_file;
 	guint timeout;
